# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class AlbumCourse:
    def __init__(self):
        self._content_id = None
        self._oper_type = None
        self._order = None

    @property
    def content_id(self):
        """
        :return:mixed
        """
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        """
        内容ID
        :param content_id:
        """
        self._content_id = content_id

    @property
    def oper_type(self):
        """
        :return:mixed
        """
        return self._oper_type

    @oper_type.setter
    def oper_type(self, oper_type):
        """
        操作类型:
        minimum:1 maximum:3
        1-add，2-delete，3-modify
        :param oper_type:
        """
        self._oper_type = oper_type

    @property
    def order(self):
        """
        :return:mixed
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        指定课程在专辑关联的列表里的位置，如果为1则该课程展示在归属的专辑中课程列表的第一位
        minimum:1 maximum:2000
        :param order:
        """
        self._order = order



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.teacher.impl.teacher_handler import TeacherHandler


class TeacherDeleteRequest:
    def __init__(self, teacher_id, reason, credential_list):
        self._teacher_id = teacher_id
        self._reason = reason
        self._teacher_handler = TeacherHandler(
            EduKitRequestSender(credential_list))

    def delete(self):
        return self._teacher_handler.delete(self._teacher_id, self._reason)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.file_upload.upload_media import UploadMedia
from edukit_sdk.edukit.common.file_upload.upload_picture import UploadPicture


class FileUploaderFactory:
    def __init__(self, file_request, request_sender):
        self._file_request = file_request
        self._request_sender = request_sender

    def get_file_uploader(self, resource_type=None):
        # 传入resource_type,使用图片上传
        if resource_type:
            return UploadPicture(self._file_request, self._request_sender)

        # 如果不指定resource_type的值,则认为上传的是媒体文件,使用UploadMedia上传
        return UploadMedia(self._file_request, self._request_sender)



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.album.impl.album_create_request import \
    AlbumCreateRequest
from edukit_sdk.edukit.album.impl.album_delete_request import \
    AlbumDeleteRequest
from edukit_sdk.edukit.album.impl.album_manage_request import \
    AlbumManageRequest
from edukit_sdk.edukit.album.impl.album_update_request import \
    AlbumUpdateRequest
from edukit_sdk.edukit.album.model.album import Album
from edukit_sdk.edukit.catalogue.impl.catalogue_create_request import \
    CatalogueCreateRequest
from edukit_sdk.edukit.catalogue.impl.catalogue_delete_request import \
    CatalogueDeleteRequest
from edukit_sdk.edukit.catalogue.impl.catalogue_update_request import \
    CatalogueUpdateRequest
from edukit_sdk.edukit.catalogue.model.catalogue import Catalogue
from edukit_sdk.edukit.catalogue.model.catalogue_edit_data import \
    CatalogueEditData
from edukit_sdk.edukit.common.log.logger import Logger
from edukit_sdk.edukit.course.impl.course_create_request import \
    CourseCreateRequest
from edukit_sdk.edukit.course.impl.course_off_shelf_request import \
    CourseOffShelfRequest
from edukit_sdk.edukit.course.impl.course_status_request import \
    CourseStatusRequest
from edukit_sdk.edukit.course.impl.course_update_request import \
    CourseUpdateRequest
from edukit_sdk.edukit.course.model.course import Course
from edukit_sdk.edukit.course.model.course_edit import CourseEdit
from edukit_sdk.edukit.learning.impl.learning_report_request import \
    LearningReportRequest
from edukit_sdk.edukit.learning.model.series_course_learning_info import \
    SeriesCourseLearningInfo
from edukit_sdk.edukit.learning.model.unitary_course_learning_info import \
    UnitaryCourseLearningInfo
from edukit_sdk.edukit.lesson.impl.lesson_create_request import \
    LessonCreateRequest
from edukit_sdk.edukit.lesson.impl.lesson_delete_request import \
    LessonDeleteRequest
from edukit_sdk.edukit.lesson.impl.lesson_update_request import \
    LessonUpdateRequest
from edukit_sdk.edukit.package.impl.pkg_create_request import PkgCreateRequest
from edukit_sdk.edukit.package.impl.pkg_delete_request import PkgDeleteRequest
from edukit_sdk.edukit.package.impl.pkg_manage_request import PkgManageRequest
from edukit_sdk.edukit.package.impl.pkg_product_delete_request import \
    PkgProductDeleteRequest
from edukit_sdk.edukit.package.impl.pkg_product_update_request import \
    PkgProductUpdateRequest
from edukit_sdk.edukit.package.impl.pkg_update_request import PkgUpdateRequest
from edukit_sdk.edukit.package.model.pkg import Pkg
from edukit_sdk.edukit.signup.impl.signup_request import SignupRequest
from edukit_sdk.edukit.signup.model.batch_report_signup_course_request import \
    BatchReportSignupCourseRequest
from edukit_sdk.edukit.signup.model.package_signup_info import \
    PackageSignupInfo
from edukit_sdk.edukit.teacher.impl.teacher_create_request import \
    TeacherCreateRequest
from edukit_sdk.edukit.teacher.impl.teacher_delete_request import \
    TeacherDeleteRequest
from edukit_sdk.edukit.teacher.impl.teacher_update_request import \
    TeacherUpdateRequest
from edukit_sdk.edukit.teacher.model.teacher import Teacher
from edukit_sdk.edukit.teacher.model.teacher_edit import TeacherEdit


class EduKitImpl:
    """
    华为教育中心EduKit服务入口类
    @author MWX1057591
    @since 2021-06-08
    """
    def __init__(self, credential_list):
        self.credential_list = credential_list
        self.logger = Logger.get_logger()

    def get_course_create_request(self, course: Course):
        return CourseCreateRequest(course, self.credential_list)

    def get_course_update_request(self, course_edit: CourseEdit):
        return CourseUpdateRequest(course_edit, self.credential_list)

    def get_course_off_shelf_request(self, course: Course):
        return CourseOffShelfRequest(course, self.credential_list)

    def get_course_status_request(self, course_id):
        return CourseStatusRequest(course_id, self.credential_list)

    def get_lesson_create_request(self, course_id, course_edit_id, lesson):
        return LessonCreateRequest(course_id, course_edit_id, lesson,
                                   self.credential_list)

    def get_lesson_delete_request(self, course_id, course_edit_id, lesson_id):
        return LessonDeleteRequest(course_id, course_edit_id, lesson_id,
                                   self.credential_list)

    def get_lesson_update_request(self, lesson_edit):
        return LessonUpdateRequest(lesson_edit, self.credential_list)

    # 通知用户课程订购状态的变更
    def get_report_signup(self, user_id, course_id, user_id_type, signup_info):
        return SignupRequest.report_signup(user_id, course_id, user_id_type,
                                           signup_info, self.credential_list)

    # 批量通知用户课程订购状态的变更
    def get_batch_report_signup_course(self, user_id, user_id_type,
                                       batch: BatchReportSignupCourseRequest):
        return SignupRequest.batch_report_signup_course(
            user_id, user_id_type, batch, self.credential_list)

    # 通知会员包订购状态的变更
    def get_report_signup_package(self, user_id, user_id_type,
                                  package: PackageSignupInfo):
        return SignupRequest.report_signup_package(user_id, user_id_type,
                                                   package,
                                                   self.credential_list)

    # 上报用户单体课学习信息
    def get_report_unitary_course_learning(self, user_id, course_id,
                                           user_id_type,
                                           unitary: UnitaryCourseLearningInfo):
        return LearningReportRequest.report_unitary_course_learning(
            user_id, course_id, user_id_type, unitary, self.credential_list)

    # 上报用户系列课学习信息
    def get_report_series_course_learning(self, user_id, course_id,
                                          user_id_type, lesson_id,
                                          series: SeriesCourseLearningInfo):
        return LearningReportRequest.report_series_course_learning(
            user_id, course_id, user_id_type, lesson_id, series,
            self.credential_list)

    # 创建专辑
    def get_create_album(self, album: Album):
        return AlbumCreateRequest(album, self.credential_list)

    # 更新专辑
    def get_update_album(self, album_id, album: Album):
        return AlbumUpdateRequest(album_id, album, self.credential_list)

    # 删除专辑
    def get_delete_album(self, album_id):
        return AlbumDeleteRequest(album_id, self.credential_list)

    # 管理专辑
    def get_manage_album(self, album_id, action, removal_reason):
        return AlbumManageRequest(album_id, action, removal_reason,
                                  self.credential_list)

    # 目录创建
    def get_catalogue_create_request(self,
                                     catalogue_edit_data: CatalogueEditData,
                                     course_id, course_edit_id):
        return CatalogueCreateRequest(catalogue_edit_data, course_id,
                                      course_edit_id, self.credential_list)

    # 目录更新
    def get_catalogue_update_request(self, catalogue: Catalogue, course_id,
                                     course_edit_id):
        return CatalogueUpdateRequest(catalogue, course_id, course_edit_id,
                                      self.credential_list)

    # 目录删除
    def get_catalogue_delete_request(self, course_id, course_edit_id,
                                     catalogue_id):
        return CatalogueDeleteRequest(course_id, course_edit_id, catalogue_id,
                                      self.credential_list)

    def get_teacher_create_request(self, teacher: Teacher):
        return TeacherCreateRequest(teacher, self.credential_list)

    def get_teacher_update_request(self, teacher_edit: TeacherEdit):
        return TeacherUpdateRequest(teacher_edit, self.credential_list)

    def get_teacher_delete_request(self, teacher_id, reason):
        return TeacherDeleteRequest(teacher_id, reason, self.credential_list)

    def get_pkg_create_request(self, pkg: Pkg):
        return PkgCreateRequest(pkg, self.credential_list)

    def get_pkg_update_request(self, pkg_id, pkg):
        return PkgUpdateRequest(pkg_id, pkg, self.credential_list)

    def get_pkg_delete_request(self, pkg_id):
        return PkgDeleteRequest(pkg_id, self.credential_list)

    def get_pkg_manage_request(self, pkg_id, action, removal_reason):
        return PkgManageRequest(pkg_id, action, removal_reason,
                                self.credential_list)

    def get_pkg_product_update_request(self, pkg_id, pkg_product_list):
        return PkgProductUpdateRequest(pkg_id, pkg_product_list,
                                       self.credential_list)

    def get_pkg_product_delete_request(self, pkg_id, pkg_edit_id, product_id):
        return PkgProductDeleteRequest(pkg_id, pkg_edit_id, product_id,
                                       self.credential_list)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging
import os
import time

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant


def debug():
    return logging.DEBUG


def info():
    return logging.INFO


def warning():
    return logging.WARNING


def error():
    return logging.ERROR


def critical():
    return logging.CRITICAL


class Logger:
    _output = '[%(asctime)s] %(filename)s[line:%(lineno)d] ' \
              '%(levelname)s:%(message)s'
    _log_path = os.path.join(CommonConstant.ROOT_PATH, CommonConstant.LOG_DIR)

    @staticmethod
    def get_logger(fh_level=info(),
                   ch_level=info(),
                   formatter=_output,
                   logfile=_log_path,
                   mode='a+'):
        """
        获取logger
        :param fh_level: 输出到file中的log的日志级别,默认为info
        :param ch_level: 输出到控制台中的log的日志级别,默认为info
        :param formatter: 输入的日志格式
        :param logfile: 日志路径,默认为_log_path
        :param mode: 日志文件的读写模式
        :return:
        """
        if not os.path.exists(logfile):
            os.makedirs(logfile)
        log_path = os.path.join(logfile, time.strftime('%Y%m%d') + '.log')

        logger = logging.getLogger()
        logger.setLevel(fh_level)

        fh = logging.FileHandler(log_path, mode)
        fh.setLevel(fh_level)  # 设置输出到file中的log的日志级别

        ch = logging.StreamHandler()
        ch.setLevel(ch_level)  # 设置输出到控制台中的log的日志级别

        formatter = logging.Formatter(formatter, datefmt='%Y-%m-%d %H:%I:%S')
        fh.setFormatter(formatter)
        ch.setFormatter(formatter)

        logger.addHandler(fh)
        logger.addHandler(ch)
        return logger



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class PkgEditMetaData:
    def __init__(self):
        self._name = None
        self._default_lang = None
        self._remarks = None
        self._eduapp_purchased = None
        self._resident_league_app = None
        self._package_name = None
        self._source_name = None
        self._dist_notify_url = None
        self._refund_notify_url = None

    @property
    def default_lang(self):
        """
        :return:mixed
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """
        缺省语言
        :param default_lang:
        :return:
        """
        self._default_lang = default_lang

    @property
    def remarks(self):
        """
        :return:mixed
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """
        提供给审核/运营人员查看的备注信息，不对最终用户呈现
        :param remarks:
        :return:
        """
        self._remarks = remarks

    @property
    def eduapp_purchased(self):
        """
        :return:mixed
        """
        return self._eduapp_purchased

    @eduapp_purchased.setter
    def eduapp_purchased(self, eduapp_purchased):
        """
        本课程是否教育中心App直购
        :param eduapp_purchased:
        :return:
        """
        self._eduapp_purchased = eduapp_purchased

    @property
    def resident_league_app(self):
        """
        :return:mixed
        """
        return self._resident_league_app

    @resident_league_app.setter
    def resident_league_app(self, resident_league_app):
        """
        该内容所属应用AppId。需要注意：
        该应用在应用市场必须存在，且必须处于上架状态
        请求时，对于门户Portal，填写应用市场AppId(类似于c100123456);
        响应时，该字段只会填应用市场AppID。
        :param resident_league_app:
        :return:
        """
        self._resident_league_app = resident_league_app

    @property
    def package_name(self):
        """
        :return:mixed
        """
        return self._package_name

    @package_name.setter
    def package_name(self, package_name):
        """
        该内容所属应用包名，最大128，数据表字段预留；
        :param package_name:
        :return:
        """
        self._package_name = package_name

    @property
    def source_name(self):
        """
        :return:mixed
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        appid为空时填写的来源信息
        :param source_name:
        :return:
        """
        self._source_name = source_name

    @property
    def dist_notify_url(self):
        """
        :return:mixed
        """
        return self._dist_notify_url

    @dist_notify_url.setter
    def dist_notify_url(self, dist_notify_url):
        """
        * CP发货商品，购买成功后的通知发货地址，由开发者指定；
        eduappPurchased = true时填写;
        :param dist_notify_url:
        :return:
        """
        self._dist_notify_url = dist_notify_url

    @property
    def name(self):
        """
        :return:mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        缺省语言名称
        :param name:
        :return:
        """
        self._name = name

    @property
    def refund_notify_url(self):
        """
        :return: mixed
        """
        return self._refund_notify_url

    @refund_notify_url.setter
    def refund_notify_url(self, refund_notify_url):
        """
        退款通知地址
        :param refund_notify_url:
        :return:
        """
        self._refund_notify_url = refund_notify_url



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.catalogue.model.catalogue_edit_data import \
    CatalogueEditData
from edukit_sdk.edukit.common.helpers.helpers import Helpers


class CatalogueEdit:
    def __init__(self):
        self._catalogue_edit_id = None
        self._edit = None

    @property
    def catalogue_edit_id(self):
        """
        :return: mixed
        """
        return self._catalogue_edit_id

    @catalogue_edit_id.setter
    def catalogue_edit_id(self, catalogue_edit_id):
        """
        课程版本ID
        :param catalogue_edit_id:
        :return:
        """
        self._catalogue_edit_id = catalogue_edit_id

    @property
    def edit(self):
        """
        :return: mixed
        """
        return self._edit

    @edit.setter
    def edit(self, edit: CatalogueEditData):
        """
        目录版本数据
        :param edit:
        :return:
        """
        self._edit = edit

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class PkgProductBriefInfo:
    def __init__(self):
        self._dev_product_id = None
        self._status = None
        self._price_list = None

    @property
    def dev_product_id(self):
        """
        :return: mixed
        """
        return self._dev_product_id

    @dev_product_id.setter
    def dev_product_id(self, dev_product_id):
        """
        商品ID,开发者指定，创建时必填，建议开发者在devProductId前拼上CP公司缩写或者其他可以保证全局唯一的标识
        :param dev_product_id:
        :return:
        """
        self._dev_product_id = dev_product_id

    @property
    def status(self):
        """
        :return: mixed
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        会员包商品状态，0-停售会员包商品，1-激活会员包商品
        :param status:
        :return:
        """
        self._status = status

    @property
    def price_list(self):
        """
        :return: mixed
        """
        return self._price_list

    @price_list.setter
    def price_list(self, price_list):
        """
        多国家定价数据，至少1个，更新时全量提交
        :param price_list:
        :return:
        """
        self._price_list = price_list



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.errorcode.abstract_error_code import \
    AbstractErrorCode


class CommonErrorCode(AbstractErrorCode):
    SUCCESS = {-0x38230000: 'Operation success.'}
    SYSTEM_ERROR = {
        0x0000:
        'System error, please check the log of eduKit SDK for more details.'
    }
    PARTIAL_SUCCESS = {
        0x0001:
        'Partial operations failed, '
        'please check all results to find the cause.'
    }
    CALL_API_INTERFACE_FAILED = {
        0x0002:
        'Call API interface failed, '
        'please check the log of eduKit SDK for more details.'
    }
    UPLOAD_FILES_FAILED = {0x1203: "Call upload interface failed."}
    PARAM_CANNOT_BE_EMPTY = {0x1204: "Parameter can not be empty!"}
    INVALID_COURSE_PARAMS = {0x1205: 'Invalid course params.'}
    INVALID_COURSE_CANCEL_COMMIT_ACTION = {
        0x1206:
        'Invalid course params, '
        'please create course first '
        'or check the updating course params.'
    }
    LESSON_ID_EMPTY = {0x1207: "Lesson ID can not be empty!"}
    NO_SUCCESSFUL_OPERATION = {
        0x1303:
        'There is no successful operation, '
        'please check all results and logs to find the cause.'
    }
    PKG_INPUT_PARAMS_INVALID = {
        0x1305: 'PkgMetaData or pkgEditData can not be null when creating pkg.'
    }
    PKG_ID_INVALID = {0x1306: 'PkgId is invalid.'}
    PKG_EDIT_ID_INVALID = {0x1307: 'Pkg edit_id is invalid.'}

    def __init__(self, error):
        self._error_code = ''
        self._error_desc = None
        for k, v in error.items():
            self._error_code = k
            self._error_desc = v

    @property
    def error_code(self):
        """
        :return:error_code
        """
        return self._error_code

    @property
    def error_desc(self):
        """
        :return:error_desc
        """
        return self._error_desc



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class PkgEdit:
    def __init__(self):
        self._meta_data = None
        self._localized_data = None
        self._pkg_products = None

    @property
    def meta_data(self):
        """
        :return:mixed
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """
        会员包版本元数据
        :param meta_data:
        :return:
        """
        self._meta_data = meta_data

    @property
    def localized_data(self):
        """
        :return:mixed
        """
        return self._localized_data

    @localized_data.setter
    def localized_data(self, localized_data):
        """
        本地化多语言数据
        :param localized_data:
        :return:
        """
        self._localized_data = localized_data

    @property
    def pkg_products(self):
        """
        :return:mixed
        """
        return self._pkg_products

    @pkg_products.setter
    def pkg_products(self, pkg_products):
        """
        商品列表信息，最大100个
        :param pkg_products:
        :return:
        """
        self._pkg_products = pkg_products



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.package.impl.pkg_handler import PkgHandler


class PkgProductDeleteRequest:
    def __init__(self, pkg_id, pkg_edit_id, product_id, credential_list):
        self._pkg_id = pkg_id
        self._pkg_edit_id = pkg_edit_id
        self._product_id = product_id
        self._pkg_handler = PkgHandler(EduKitRequestSender(credential_list))

    def delete(self):
        return self._pkg_handler.delete(self._pkg_id, self._pkg_edit_id,
                                        self._product_id)



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class OrderInfo:
    def __init__(self):
        self._order_id = None
        self._order_time = None
        self._pay_order_id = None

    @property
    def order_id(self):
        """
        :return: order_id
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """
        设置用户购买课程/会员包时，华为应用内支付服务生成的订单ID。
        对于教育中心直购的场景，应从商品发货通知接口中的order_id字段获取订单号上报。
        对于在您的APP中直接产生的课程/会员包购买，应上报HMS应用内支付服务返回的order_id。
        如果您接入应用内支付V2.0，可以通过支付成功后客户端回调接口中的PayResultInfo对象，或者服务端回调接口中获得order_id。
        如果您接入应用内支付V3.0及以上版本，可以通过支付成功后onActivityResult返回的InAppPurchaseData对象获得order_id。
        对于用户续订时产生的订购关系同步，应上报续订操作行为对应的order_id。
        :param order_id:
        :return:
        """
        self._order_id = order_id

    @property
    def order_time(self):
        """
        :return:
        """
        return self._order_time

    @order_time.setter
    def order_time(self, order_time):
        """
        订单完成的时间，使用RFC3339定义的UTC时间格式(即GMT+00时区的时间)。
        :param order_time:
        :return:
        """
        self._order_time = order_time

    @property
    def pay_order_id(self):
        """
        :return:
        """
        return self._pay_order_id

    @pay_order_id.setter
    def pay_order_id(self, pay_order_id):
        """
        设置用户购买课程/会员包时，华为支付平台生成的订单ID。
        仅当用户直接在您的APP中购买课程/会员包，且您接入华为应用内支付V3.0服务时，才需要上报此字段。
        您可以通过支付成功后onActivityResult返回的InAppPurchaseData对象获得pay_order_id。
        对于用户续订时产生的订购关系同步，应上报续订操作行为对应的pay_order_id。
        :param pay_order_id:
        :return:
        """
        self._pay_order_id = pay_order_id

    def to_json_string(self):
        """
        to_string
        :return:
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class TeacherMetaData:
    def __init__(self):
        self._famous_flag = None
        self._default_lang = None

    @property
    def famous_flag(self):
        """
        :return: mixed
        """
        return self._famous_flag

    @famous_flag.setter
    def famous_flag(self, famous_flag):
        """
        该教师是否为名师，说明如下：
        教育中心App有名师专区栏目，将教师标识为名师将有可能在该栏目中出现
        此字段在教师信息首次提交审核时必须指定；后续更新时可不携带，此时将保持当前取值不变
        :param famous_flag:
        :return:
        """
        self._famous_flag = famous_flag

    @property
    def default_lang(self):
        """
        :return: mixed
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """
        课程的默认语言代码。说明如下：
        您可以提供多语言的教师信息；教育中心客户端向用户展示教师时，会优先匹配用户设备设置的系统语言。
        如您未提供用户系统语言对应的教师信息，将展示默认语言对应的数据
        语言代码由BCP-47定义，如简体中文为"zh-CN"，区分大小写（语言标识使用小写字母；区域名称使用大写字母）
        :param default_lang:
        :return:
        """
        self._default_lang = default_lang

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class HttpConstant:
    # 请求头
    CONTENT_TYPE = 'Content-Type'
    APPLICATION_JSON = 'application/json'
    MULTIPART_FROM_DATA = 'multipart/form-data'
    APPLICATION_URLENCODED = 'application/x-www-form-urlencoded'
    HEAD_AUTHORIZATION = 'Authorization'
    HEAD_CLIENT_ID = 'client_id'
    HEAD_USER_AGENT = 'User-Agent'

    # 请求方法
    REQUEST_METHOD_GET = 'GET'
    REQUEST_METHOD_POST = 'POST'
    REQUEST_METHOD_PUT = 'PUT'
    REQUEST_METHOD_DELETE = 'DELETE'

    # curl配置
    VERIFYHOST_TYPE_COMMON_NAME = 1
    VERIFYHOST_TYPE_MATCH_HOST_NAME = 2



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.catalogue.model.catalogue_full_localized_data import \
    CatalogueFullLocalizedData
from edukit_sdk.edukit.catalogue.model.catalogue_full_meta_data import \
    CatalogueFullMetaData
from edukit_sdk.edukit.common.helpers.helpers import Helpers


class CatalogueEditData:
    def __init__(self):
        self._meta_data = None
        self._localized_data = None
        self._delete_language_list = None

    @property
    def meta_data(self):
        """
        :return: mixed
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data: CatalogueFullMetaData):
        """
        目录完整元数据
        :param meta_data:
        :return:
        """
        self._meta_data = meta_data

    @property
    def localized_data(self):
        """
        :return: mixed
        """
        return self._localized_data

    @localized_data.setter
    def localized_data(self, localized_data: CatalogueFullLocalizedData):
        """
        目录完整多语言数据
        :param localized_data:
        :return:
        """
        self._localized_data = localized_data

    @property
    def delete_language_list(self):
        """
        :return: mixed
        """
        return self._delete_language_list

    @delete_language_list.setter
    def delete_language_list(self, delete_language_list):
        """
        需要删除的多语言数据,语言代码，由BCP-47定义
        :param delete_language_list:
        :return:
        """
        self._delete_language_list = delete_language_list

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.model.response import Response
from edukit_sdk.edukit.learning.impl.learning_handler import LearningHandler


class LearningReportRequest:
    @staticmethod
    def report_unitary_course_learning(
            user_id,
            course_id,
            user_id_type,
            unitary_course_learning_info,
            credential_list):
        response = Response()
        if Helpers.has_empty_param(
                [user_id, course_id, user_id_type,
                 unitary_course_learning_info]):
            response.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return response
        learning_handler = LearningHandler(
            EduKitRequestSender(credential_list))
        return learning_handler.report_unitary_course_learning(
            user_id, course_id, user_id_type, unitary_course_learning_info)

    @staticmethod
    def report_series_course_learning(user_id, course_id, user_id_type,
                                      lesson_id,
                                      series_course_learning_info,
                                      credential_list):
        response = Response()
        if Helpers.has_empty_param([user_id, course_id, user_id_type,
                                    lesson_id, series_course_learning_info]):
            response.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return response
        learning_handler = LearningHandler(
            EduKitRequestSender(credential_list))
        return learning_handler.report_series_course_learning(
            user_id, course_id, user_id_type, lesson_id,
            series_course_learning_info)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CatalogueFullMetaData:
    def __init__(self):
        self._name = None
        self._default_lang = None
        self._parent_id = None
        self._display_order = None
        self._create_time = None
        self._last_update = None

    @property
    def parent_id(self):
        """
        :return: mixed
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """
        父目录ID，创建子目录时携带，不携带时，默认创建一级目录
        :param parent_id:
        :return:
        """
        self._parent_id = parent_id

    @property
    def display_order(self):
        """
        :return: mixed
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """
        同一课程目录列表中该目录的排列顺序
        :param display_order:
        :return:
        """
        self._display_order = display_order

    @property
    def default_lang(self):
        """
        :return: mixed
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """
        目录的默认语言代码
        :param default_lang:
        :return:
        """
        self._default_lang = default_lang

    @property
    def create_time(self):
        """
        :return: mixed
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """
        目录创建时间，order相同时，按创建时间从早到晚排序， 使用RFC3339定义的UTC时间格式
        :param create_time:
        :return:
        """
        self._create_time = create_time

    @property
    def name(self):
        """
        :return: mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        目录名称
        :param name:
        :return:
        """
        self._name = name

    @property
    def last_update(self):
        """
        :return: mixed
        """
        return self._last_update

    @last_update.setter
    def last_update(self, last_update):
        """
        目录版本更新时间，使用RFC3339定义的UTC时间格式
        :param last_update:
        :return:
        """
        self._last_update = last_update



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.album.impl.album_handler import AlbumHandler
from edukit_sdk.edukit.album.resp.create_album_response import \
    CreateAlbumResponse
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender


class AlbumCreateRequest:
    def __init__(self, album, credential_list):
        self.__album = album
        self.__album_handler = AlbumHandler(
            EduKitRequestSender(credential_list))

    def create(self):
        formatted_album = self.__album_handler.format_data(self.__album)
        if not formatted_album:
            create_album_response = CreateAlbumResponse()
            create_album_response.result = Helpers.build_error_result(
                    CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return create_album_response
        return self.__album_handler.create_album(formatted_album)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.catalogue.model.catalogue_edit import CatalogueEdit


class Catalogue:
    def __init__(self):
        self._catalogue_id = None
        self._catalogue_edit = None

    @property
    def catalogue_id(self):
        """
        :return: mixed
        """
        return self._catalogue_id

    @catalogue_id.setter
    def catalogue_id(self, catalogue_id):
        """
        目录ID
        :param catalogue_id:
        :return:
        """
        self._catalogue_id = catalogue_id

    @property
    def catalogue_edit(self):
        """
        :return: mixed
        """
        return self._catalogue_edit

    @catalogue_edit.setter
    def catalogue_edit(self, catalogue_edit: CatalogueEdit):
        """
        目录版本数据
        :param catalogue_edit:
        :return:
        """
        self._catalogue_edit = catalogue_edit



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class SeriesCourseLearningInfo:
    def __init__(self):
        self._start_time = None
        self._course_learning_status = None
        self._lesson_learning_status = None

    @property
    def start_time(self):
        """
        :return:mixed
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        设置本次学习开始时间。
        使用RFC3339定义的UTC时间格式(即GMT+00时区的时间)，例：2021-12-20T08:00:00Z。
        :param start_time:
        :return:
        """
        self._start_time = start_time

    @property
    def course_learning_status(self):
        """
        :return:mixed
        """
        return self._course_learning_status

    @course_learning_status.setter
    def course_learning_status(self, course_learning_status):
        """
        设置本次学习结束后，课程整体学习完成状态，1表示正在学，2表示已学完。
        如上报的学习状态为2，则该课程将标记为"学习完成"状态。上报课程整体状态为已学完不要求课程下所有章节的状态都为已学完。
        如未上报课程整体学习状态，教育中心将根据上报的章节状态自动计算课程整体的学习状态，计算方式为“课程下所有章节已学完则课程学习状态为已学完”。

        :param course_learning_status:
        :return:
        """
        self._course_learning_status = course_learning_status

    @property
    def lesson_learning_status(self):
        """
        :return:mixed
        """
        return self._lesson_learning_status

    @lesson_learning_status.setter
    def lesson_learning_status(self, lesson_learning_status):
        """
        设置本次学习结束后，章节学习完成状态。
        1-正在学，表示用户已经开始学习该章节但是尚未完成；2-已学完，表示用户已经完成该章节的学习。
        :param lesson_learning_status:
        :return:
        """
        self._lesson_learning_status = lesson_learning_status

    def to_json_string(self):
        """
        将对象转为JSON字符串
        :return:
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.lesson.constant.lesson_constant import LessonConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.lesson.model.lesson import Lesson
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.model.response import Response
from edukit_sdk.edukit.common.util.update_data_util import UpdateDataUtil
from edukit_sdk.edukit.course.impl.update_localized_data_request import \
    UpdateLocalizedDataRequest
from edukit_sdk.edukit.lesson.impl.create_lesson_edit_request import \
    CreateLessonEditRequest
from edukit_sdk.edukit.lesson.impl.create_lesson_request import \
    CreateLessonRequest
from edukit_sdk.edukit.lesson.impl.create_lesson_result import \
    CreateLessonResult
from edukit_sdk.edukit.lesson.impl.update_lesson_result import \
    UpdateLessonResult
from edukit_sdk.edukit.lesson.impl.update_meta_data_request import \
    UpdateMetaDataRequest
from edukit_sdk.edukit.lesson.model.lesson_edit import LessonEdit
from edukit_sdk.edukit.lesson.resp.lesson_create_response import \
    LessonCreateResponse
from edukit_sdk.edukit.lesson.resp.lesson_update_response import \
    LessonUpdateResponse


class LessonHandler:
    def __init__(self, request_sender: EduKitRequestSender):
        """
        :param request_sender:
        """
        self._request_sender = request_sender

    def create_lesson(self, course_id, course_edit_id, lesson: Lesson):
        response = CreateLessonResult()
        try:
            url = ApiConstant.LESSON_CREATE_URL.format(course_id,
                                                       course_edit_id)
            create_lesson_request = CreateLessonRequest()
            if lesson.meta_data and lesson.meta_data.display_order:
                create_lesson_request.display_order = \
                    lesson.meta_data.display_order
            if lesson.catalogue_id:
                create_lesson_request.catalogue_id = lesson.catalogue_id
            http_common_response = HttpCommonResponse(
                self._request_sender.post(
                    url=url, body=create_lesson_request.to_bytes()))
            response = Helpers.parse_response(
                http_common_response.get_rsp(),
                LessonConstant.CreateLessonResult)
        except EduKitException as e:
            logging.info(
                'Call create lesson interface failed. ErrorMessage: %s' %
                e.message)
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        return response

    def update_lesson_data(self, course_id, course_edit_id, lesson_id,
                           lesson_edit_id, lesson: Lesson,
                           rsp: LessonUpdateResponse):
        # 更新章节元数据
        update_lesson_meta_data_result = self._update_lesson_meta_data(
            course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)
        rsp.update_lesson_meta_data_result = update_lesson_meta_data_result
        if update_lesson_meta_data_result and \
                update_lesson_meta_data_result.result:
            if update_lesson_meta_data_result.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                result_code = update_lesson_meta_data_result.result.result_code
                result_desc = update_lesson_meta_data_result.result.result_desc
                logging.error(
                    'Update lesson metadata failed and result_code: %s,'
                    'error_message: %s  ' % (result_code, result_desc))
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.PARTIAL_SUCCESS)
                return rsp
            else:
                logging.info('Update lesson metadata end')

        # 更新章节本地化多语言数据
        update_lesson_localized_data_result = \
            self._update_multi_language_data_list(
                course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)
        rsp.update_localized_data_result = update_lesson_localized_data_result
        if update_lesson_localized_data_result and \
                update_lesson_localized_data_result.result:
            if update_lesson_localized_data_result.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Update lesson localized data failed and result_code: %s,'
                    'error_message: %s ' %
                    (update_lesson_localized_data_result.result.result_code,
                     update_lesson_localized_data_result.result.result_desc))
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.PARTIAL_SUCCESS)
                return rsp
            else:
                logging.info('Update localized data end')

        if lesson.language_list_to_delete:
            delete_localized_data_result = self._delete_localized_data(
                course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)
            rsp.delete_localized_data_result = delete_localized_data_result
            if delete_localized_data_result and \
                    delete_localized_data_result.result and \
                    delete_localized_data_result.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.PARTIAL_SUCCESS)
                return rsp
        rsp.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        return rsp

    def update_lesson_data_create(self, course_id, course_edit_id, lesson_id,
                                  lesson_edit_id, lesson: Lesson,
                                  rsp: LessonCreateResponse):
        update_lesson_meta_data_result = self._update_lesson_meta_data(
            course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)
        rsp.update_lesson_meta_data_result = update_lesson_meta_data_result
        if update_lesson_meta_data_result and \
                update_lesson_meta_data_result.result:
            if update_lesson_meta_data_result.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Update lesson metadata failed and result_code: %s,'
                    'error_message: %s  '
                    % (update_lesson_meta_data_result.result.result_code,
                       update_lesson_meta_data_result.result.result_desc))
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.PARTIAL_SUCCESS)
                return rsp
            else:
                logging.info('Update lesson metadata end')

        update_create_localized_data_result = \
            self._update_multi_language_data_list(
                course_id, course_edit_id, lesson_id, lesson_edit_id, lesson)

        rsp.update_localized_data_result = update_create_localized_data_result
        if update_create_localized_data_result and \
                update_create_localized_data_result.result:
            if update_create_localized_data_result.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Update lesson localized data failed and result_'
                    'code: %s,error_message: %s '
                    % (update_create_localized_data_result.result.result_code,
                       update_create_localized_data_result.result.result_desc))
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.PARTIAL_SUCCESS)
                return rsp
            else:
                logging.info('Update lesson localized data end')

        rsp.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        return rsp

    def _update_lesson_meta_data(self, course_id, course_edit_id, lesson_id,
                                 lesson_edit_id, lesson: Lesson):
        response = Response()
        if not lesson.meta_data:
            logging.info(
                'Lesson metadata is empty, courseId = %s, courseEditId = %s, '
                'lessonId = %s, lessonEditId = %s.'
                % (course_id, course_edit_id, lesson_id, lesson_edit_id))

            return response
        logging.info(
            'Update lesson metadata begin, courseId = %s, courseEditId = %s, '
            'lessonId = %s, lessonEditId = %s, '
            'lessonName = %s' % (course_id, course_edit_id, lesson_id,
                                 lesson_edit_id, lesson.meta_data.name))

        update_meta_data_request = UpdateMetaDataRequest()
        update_meta_data_request.meta_data = lesson.meta_data

        try:
            url = ApiConstant.LESSON_METADATA_URL.format(
                course_id, course_edit_id, lesson_id, lesson_edit_id)
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=update_meta_data_request.to_bytes()))
            response = Helpers.parse_response(http_common_response.get_rsp(),
                                              LessonConstant.RESPONSE)
        except EduKitException as e:
            logging.info(
                'Call update lesson metadata interface failed. '
                'ErrorMessage: %s' % e.message)
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        return response

    def _update_multi_language_data_list(self, course_id, course_edit_id,
                                         lesson_id, lesson_edit_id,
                                         lesson: Lesson):
        response = Response()
        if not lesson.multi_lang_localized_data_list:
            logging.info(
                'Lesson multi_lang_localized_data_list is empty, '
                'courseId = %s, courseEditId = %s, lessonId = %s, '
                'lessonEditId = %s.' %
                (course_id, course_edit_id, lesson_id, lesson_edit_id))

            return response
        logging.info(
            'Update lesson localized data begin, courseId = %s, '
            'courseEditId = %s, lessonId = %s, lessonEditId = %s, '
            % (course_id, course_edit_id, lesson_id, lesson_edit_id))
        response.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        for item in lesson.multi_lang_localized_data_list:
            update_localized_data_request = UpdateLocalizedDataRequest()
            update_localized_data_request.localized_data = \
                item.lesson_localized_data
            if item.media_localized_data:
                update_localized_media_result_list = list()
                single_result = UpdateDataUtil.update_multi_language_data(
                    item.media_localized_data, self._request_sender)
                if not single_result:
                    response.result = Helpers.build_error_result(
                        CommonErrorCode.CALL_API_INTERFACE_FAILED)
                    return response
                update_localized_media_result_list.append(single_result)
                update_localized_data_request.localized_media = \
                    update_localized_media_result_list

            update_localized_data_rsp = self._update_localized_data(
                course_id, course_edit_id, lesson_id, lesson_edit_id,
                update_localized_data_request, item.language)
            if update_localized_data_rsp and update_localized_data_rsp.result \
                    and update_localized_data_rsp.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                response = update_localized_data_rsp
                break
        return response

    def _update_localized_data(
            self, course_id, course_edit_id, lesson_id, lesson_edit_id,
            update_localized_data_request: UpdateLocalizedDataRequest, lang):
        response = Response()
        try:
            url = ApiConstant.LESSON_LOCALIZED_DATA_URL.format(
                course_id, course_edit_id, lesson_id, lesson_edit_id, lang)
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=update_localized_data_request.to_bytes()))
            response = Helpers.parse_response(http_common_response.get_rsp(),
                                              LessonConstant.RESPONSE)
        except EduKitException as e:
            logging.info(
                'Call update lesson localized data interface failed. '
                'ErrorMessage: %s'
                % e.message)
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        return response

    def _delete_localized_data(self, course_id, course_edit_id, lesson_id,
                               lesson_edit_id, lesson: Lesson):
        response = Response()
        for language in lesson.language_list_to_delete:
            logging.info(
                'Delete lesson language begin, courseId = %s, '
                'courseEditId = %s, lessonId = %s, lessonEditId = %s, '
                'language = %s' % (course_id, course_edit_id, lesson_id,
                                   lesson_edit_id, language))
            try:
                url = ApiConstant.LESSON_LOCALIZED_DATA_URL.format(
                    course_id, course_edit_id, lesson_id, lesson_edit_id,
                    language)
                http_common_response = HttpCommonResponse(
                    self._request_sender.delete(url=url))
                result = Helpers.parse_response(http_common_response.get_rsp(),
                                                LessonConstant.RESPONSE)
                if result and result.result and result.result.result_code != \
                        CommonConstant.RESULT_SUCCESS:
                    logging.error(
                        'Delete lesson language failed and courseId = %s, '
                        'courseEditId = %s, '
                        'lessonId = %s, lessonEditId = %s, language = %s, '
                        'result_code: %s,error_message: %s'
                        % (course_id, course_edit_id, lesson_id,
                           lesson_edit_id, language, result.result.result_code,
                           result.result.result_desc))
                    response.result = result.result
                    return response
            except EduKitException as e:
                logging.error(
                    'Delete lesson language failed and courseId = %s, '
                    'courseEditId = %s, '
                    'lessonId = %s, lessonEditId = %s, language = %s, '
                    'errorCode:%s, errormessage:%s'
                    % (course_id, course_edit_id, lesson_id, lesson_edit_id,
                       language, e.message, e.code))
                response.result = Helpers.build_error_result(
                    CommonErrorCode.CALL_API_INTERFACE_FAILED)
                return response
            logging.info(
                'Delete lesson language end, courseId = %s, courseEditId = %s,'
                ' lessonId = %s, lessonEditId = %s, language = %s' %
                (course_id, course_edit_id, lesson_id,
                 lesson_edit_id, language))

        response.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        return response

    def create_lesson_new_edit(self, lesson_edit: LessonEdit,
                               force_create_new_edit):
        response = UpdateLessonResult()
        if not lesson_edit.lesson.lesson_id:
            response.result = Helpers.build_error_result(
                CommonErrorCode.LESSON_ID_EMPTY)
            return response
        logging.info('Create lesson new edit begin')
        create_lesson_edit_request = CreateLessonEditRequest()
        create_lesson_edit_request.force_create_new_edit = \
            force_create_new_edit

        try:
            url = ApiConstant.LESSON_URL.format(lesson_edit.course_id,
                                                lesson_edit.course_edit_id,
                                                lesson_edit.lesson.lesson_id)
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=create_lesson_edit_request.to_bytes()))
            response = Helpers.parse_response(
                http_common_response.get_rsp(),
                LessonConstant.UPDATE_LESSON_RESULT)
        except EduKitException as e:
            logging.info(
                'Call create lesson new edit interface failed. code:%s '
                'ErrorMessage: %s'
                % (e.code, e.message))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        return response

    def delete_lesson(self, course_id, course_edit_id, lesson_id):
        logging.info(
            'Delete lesson begin, courseId = %s, courseEditId = %s, '
            'lessonId = %s'
            % (course_id, course_edit_id, lesson_id))
        response = Response()
        try:
            url = ApiConstant.LESSON_URL.format(course_id, course_edit_id,
                                                lesson_id)
            http_common_response = HttpCommonResponse(
                self._request_sender.delete(url=url))
            response = Helpers.parse_response(http_common_response.get_rsp(),
                                              LessonConstant.RESPONSE)
            if response and response.result and response.result.result_code \
                    != CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Delete lesson failed and result_code: %s,error_message: '
                    '%s' % (response.result.result_code,
                            response.result.result_desc))
                return response
        except EduKitException as e:
            logging.info(
                'Call delete lesson interface failed. ErrorMessage: %s' %
                e.message)
            response.result(
                Helpers.build_error_result(
                    CommonErrorCode.CALL_API_INTERFACE_FAILED))
            return response
        logging.info(
            'Delete lesson end, courseId = %s, courseEditId = %s, '
            'lessonId = %s' % (course_id, course_edit_id, lesson_id))
        return response

    def reset_lesson(self, course_id, course_edit_id, lesson_id):
        logging.info(
            'Reset lesson begin, courseId = %s, courseEditId = %s, '
            'lessonId = %s'
            % (course_id, course_edit_id, lesson_id))
        response = Response()
        try:
            url = ApiConstant.LESSON_RESET_URL.format(course_id,
                                                      course_edit_id,
                                                      lesson_id)
            http_common_response = HttpCommonResponse(
                self._request_sender.delete(url=url))
            response = Helpers.parse_response(http_common_response.get_rsp(),
                                              LessonConstant.RESPONSE)
            if response and response.result and response.result.result_code \
                    != CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Reset lesson interface failed and result_code: %s,'
                    'error_message: %s'
                    %
                    (response.result.result_code, response.result.result_desc))
                return response
        except EduKitException as e:
            logging.error(
                'Call reset lesson interface failed. ErrorMessage: %s' %
                e.message)
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        logging.info(
            'Reset lesson end, courseId = %s, courseEditId = %s, lessonId = %s'
            % (
                course_id,
                course_edit_id,
                lesson_id,
            ))
        return response



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CreateCourseResult:
    def __init__(self, edit_id=None, course_id=None, result=None):
        self._edit_id = edit_id
        self._course_id = course_id
        self._result = result

    @property
    def edit_id(self):
        return self._edit_id

    @edit_id.setter
    def edit_id(self, edit_id):
        self._edit_id = edit_id

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, result):
        self._result = result

    @property
    def course_id(self):
        return self._course_id

    @course_id.setter
    def course_id(self, course_id):
        self._course_id = course_id



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.course.impl.change_course_status_request import \
    ChangeCourseStatusRequest
from edukit_sdk.edukit.course.impl.course_handler import CourseHandler
from edukit_sdk.edukit.course.impl.create_course_result import \
    CreateCourseResult
from edukit_sdk.edukit.course.model.course import Course
from edukit_sdk.edukit.course.resp.course_create_response import \
    CourseCreateResponse


class CourseCreateRequest:
    def __init__(self, course: Course, credential_list):
        self._course = course
        self._course_handler = CourseHandler(
            EduKitRequestSender(credential_list))

    def save_draft(self):
        logging.info('CreatCourse saveDraft task start.')
        create_course_result = self._course_handler.create_course()
        course_create_response = CourseCreateResponse()
        if create_course_result and create_course_result.result and \
                create_course_result.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            logging.error('CreateCourse failed and result: %s',
                          create_course_result.result)
            course_create_response.result = create_course_result.result
            return course_create_response

        if not self._course:
            logging.info(
                'An empty course is created and course_id:%s, edit_id:%s',
                create_course_result.course_id, create_course_result.edit_id)
            course_create_response.course_id(create_course_result.course_id)
            course_create_response.edit_id(create_course_result.edit_id)
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.SUCCESS)
            return course_create_response

        update_course_result = self._course_handler.update_course(
            self._course, create_course_result)
        if update_course_result:
            course_create_response.edit_id = create_course_result.edit_id
            course_create_response.course_id = create_course_result.course_id
            course_create_response.update_localized_data_result = \
                Helpers.build_error_result(
                    CommonErrorCode.SUCCESS)
            course_create_response.update_meta_data_result = \
                Helpers.build_error_result(
                    CommonErrorCode.SUCCESS)
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.SUCCESS)
            course_create_response.update_product_price_result = \
                Helpers.build_error_result(
                    CommonErrorCode.SUCCESS)
        else:
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        logging.info('CreatCourse saveDraft task end.')
        return course_create_response

    def commit(self, action):
        course_create_response = CourseCreateResponse()
        create_course_result = self._course_handler.create_course()
        if create_course_result and create_course_result.result and \
                create_course_result.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            logging.error('CreateCourse failed and result: %s',
                          create_course_result.result.result_desc)
            course_create_response.result = create_course_result.result
            return course_create_response

        logging.info('CreatCourse commit task start.')
        change_course_status_request = ChangeCourseStatusRequest()
        change_course_status_request.action = action
        if not self._check_create_course_params(create_course_result,
                                                course_create_response):
            return course_create_response

        update_course_result = self._course_handler.update_course(
            self._course, create_course_result)
        if not update_course_result:
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return course_create_response

        course_create_response.course_id = create_course_result.course_id
        course_create_response.edit_id = create_course_result.edit_id
        course_create_response.update_meta_data_result = \
            Helpers.build_error_result(
                CommonErrorCode.SUCCESS)
        course_create_response.update_localized_data_result = \
            Helpers.build_error_result(
                CommonErrorCode.SUCCESS)
        course_create_response.update_product_price_result = \
            Helpers.build_error_result(
                CommonErrorCode.SUCCESS)
        course_create_response.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)

        return self._course_commit(course_create_response,
                                   change_course_status_request)

    def _check_create_course_params(
            self, create_course_result: CreateCourseResult,
            course_create_response: CourseCreateResponse):
        if not self._course:
            logging.error(
                'Course can not be null when committing course and '
                'course_id:%s, edit_id:%s' %
                (create_course_result.course_id, create_course_result.edit_id))
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return False

        if not self._course.course_meta_data:
            logging.error(
                'Course metaData can not be null when committing course '
                'and course_id:%s, edit_id:%s' %
                (create_course_result.course_id, create_course_result.edit_id))
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return False

        if not self._course.course_multi_language_data_list:
            logging.error(
                'Course localizedData can not be null when committing course '
                'and course_id:%s, edit_id:%s' %
                (create_course_result.course_id, create_course_result.edit_id))
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return False

        return True

    def _course_commit(
            self, course_create_response: CourseCreateResponse,
            change_course_status_request: ChangeCourseStatusRequest):
        if course_create_response and course_create_response.result and \
                course_create_response.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            return course_create_response

        commit_result = self._course_handler.commit_course(
            course_create_response.course_id, course_create_response.edit_id,
            self._course, change_course_status_request)
        if commit_result and commit_result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            course_create_response.result = Helpers.build_error_result(
                CommonErrorCode.PARTIAL_SUCCESS)

        course_create_response.commit_result = commit_result

        logging.info('CreatCourse commit task end.')
        return course_create_response



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ProductPrice:
    def __init__(self):
        self._country_code = None
        self._price_type = None
        self._price = None

    @property
    def country_code(self):
        return self._country_code

    """
     * 价格对应的国家/地区代码。
     * 使用[ISO-3166-1]定义的两位字符形式的国家代码。如中国为"CN"。
     * 国家代码需要使用大写字符形式。
     * 最大长度 : 10
     * 示例: "CN"
     * :param: mixed country_code
     * :return: ProductPrice
    """

    @country_code.setter
    def country_code(self, country_code):
        self._country_code = country_code

    @property
    def price_type(self):
        return self._price_type

    """
     * 价格类型， 支持原始价格和售卖价格两种类型：
     * 1: 原始价格。可用在降价促销等场景展示商品原始价格；教育中心App显示原价时，将使用删除线进行标识。
     * 2: 售卖价格。用户购买商品时实际需要支付的价格。
     * 说明：
     * 原始价格为可选字段，如不指定则只展示售卖价格。
     * 售卖价格必须小于原始价格，否则将返回错误。
     * :param: mixed price_type
     * :return: ProductPrice
    """

    @price_type.setter
    def price_type(self, price_type):
        self._price_type = price_type

    @property
    def price(self):
        return self._price

    """
     * 商品价格。
     * 价格对应的货币单位由countryCode代表的国家确定。每个国家默认的货币单位可联系华为运营人员获取。
     * 价格单位为基准货币单位(即"元")。
     * 价格最多支持19位数字(包含小数部分)，最多支持2位小数。
     * 部分货币类型只支持整数，不支持小数。具体可参考[ISO-4217]exponent部分为0的货币。
     * 示例: 99.9
     * :param: mixed price
     * :return: ProductPrice
    """

    @price.setter
    def price(self, price):
        self._price = price



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.common.model.image_file_info import ImageFileInfo


class TeacherLocalizedData:
    def __init__(self):
        self._language = None
        self._name = None
        self._description = None
        self._teacher_portrait = None
        self._portrait_id = None

    @property
    def name(self):
        """
        :return: mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        教师姓名
        最大30字符（1个汉字也算1个字符）
        对于每种已添加的语言类型，提交教师信息前必须指定此字段。后续更新时可不携带此字段，此时将保留当前值不变
        :param name:
        :return:
        """
        self._name = name

    @property
    def description(self):
        """
        :return: mixed
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        教师介绍
        最大500字符（1个汉字也算1个字符）
        对于每种已添加的语言类型，提交教师信息前必须指定此字段。后续更新时可不携带此字段，此时将保留当前值不变
        :param description:
        :return:
        """
        self._description = description

    @property
    def teacher_portrait(self):
        """
        :return: mixed
        """
        return self._teacher_portrait

    @teacher_portrait.setter
    def teacher_portrait(self, teacher_portrait: ImageFileInfo):
        """
        上传文件信息 详见ImageFileInfo类
        :param teacher_portrait:
        :return:
        """
        self._teacher_portrait = teacher_portrait

    @property
    def portrait_id(self):
        """
        :return: mixed
        """
        return self._portrait_id

    @portrait_id.setter
    def portrait_id(self, portrait_id):
        self._portrait_id = portrait_id

    @property
    def language(self):
        """
        :return: mixed
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        教师语言信息
        语言代码由BCP-47定义，如简体中文为"zh-CN"，区分大小写（语言标识使用小写字母；区域名称使用大写字母）
        :param language:
        :return:
        """
        self._language = language


#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json
import logging
import time

from edukit_sdk.edukit.common.config.config import Config
from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.constant.error_constant import ErrorConstant
from edukit_sdk.edukit.common.constant.http_constant import HttpConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.http.client import Client
from edukit_sdk.edukit.common.http.request import Request


class AuthTokenCredential:
    token_memory = {}

    def __init__(
        self,
        credential_list: dict,
        client=None,
    ):
        credential = self.__get_client(credential_list)
        self._token = AuthTokenCredential.token_memory.get('access_token')
        self._expire = AuthTokenCredential.token_memory.get('cached_expire')
        self._client_id = credential.get('client_id')
        self._client_secret = credential.get('client_secret')
        config = Config()
        self._domain = config.get_domain()
        if client is None:
            self._client = Client()
        else:
            self._client = client

    def get_client_id(self):
        return self._client_id

    def get_token(self):
        cached_client_id = AuthTokenCredential.token_memory.get(
            'cached_client_id')
        cached_token = AuthTokenCredential.token_memory.get('cached_token')
        cached_expire = AuthTokenCredential.token_memory.get('cached_expire')
        cached_time = AuthTokenCredential.token_memory.get('cached_time')

        # 检测token是否有效,是否过期
        if self.__is_cached_token_valid(cached_client_id, cached_token,
                                        cached_expire, cached_time):
            logging.info('Got token from cache.')
            return cached_token
        try:
            self.__refresh_token()

            if not self._token:
                token_body = self.__obtain_token()
                if token_body:
                    self._token = token_body.get('access_token')
        except EduKitException as e:
            raise EduKitException('Get token failed! '
                                  'ErrorMessage:{}'.format(str(e)))

        return self._token

    def __refresh_token(self):
        """
        刷新token
        :return:
        """
        try:
            cached_client_id = AuthTokenCredential.token_memory.get(
                'cached_client_id')
            cached_token = AuthTokenCredential.token_memory.get('cached_token')
            cached_expire = AuthTokenCredential.token_memory.get(
                'cached_expire')
            cached_time = AuthTokenCredential.token_memory.get('cached_time')
            if self.__is_cached_token_valid(cached_client_id, cached_token,
                                            cached_expire, cached_time):
                logging.info('Access token has been refreshed.')
                return

            token_body = self.__obtain_token()
            if token_body:
                self._token = token_body.get('access_token')
                self._expire = token_body.get('expires_in')

                cached_token = {
                    'cached_client_id': self._client_id,
                    'cached_token': self._token,
                    'cached_expire': self._expire,
                    'cached_time': time.time()
                }

                AuthTokenCredential.token_memory = cached_token
        except EduKitException as e:
            raise EduKitException(str(e))

    def __obtain_token(self):
        url = self._domain + ApiConstant.TOKEN_URL
        body = {
            "client_id": self._client_id,
            "client_secret": self._client_secret,
            "grant_type": "client_credentials"
        }
        logging.info('Obtaining token from remote.')
        body = bytes(json.dumps(body), encoding=ClientConstant.UTF_8)
        headers = {HttpConstant.CONTENT_TYPE: HttpConstant.APPLICATION_JSON}
        try:
            rsp = self._client.send_request(
                Request(url=url,
                        method=HttpConstant.REQUEST_METHOD_POST,
                        headers=headers,
                        body=body))
            if rsp and not rsp.get_error() and rsp.get_rsp() and rsp.get_rsp(
            ).get('error') == CommonConstant.RESULT_SUCCESS:
                return rsp.get_rsp()
        except Exception as e:
            raise EduKitException(str(e))

    def __get_client(self, credential_list):
        """
        获取用户信息
        :param credential_list: 包含client_id和client_secret
        :return:
        """
        if self.__is_credential_valid(credential_list):
            return credential_list
        raise EduKitException(ErrorConstant.CREDENTIAL_IS_EMPTY)

    def __is_cached_token_valid(self, cached_client_id, cached_token,
                                cached_expire, cached_token_time) -> bool:
        """
        缓存的token是否有效,True为有效
        :param cached_client_id: 缓存token对应的用户id
        :param cached_token: 缓存token
        :param cached_expire: 设置的缓存过期时间(默认为2天)
        :param cached_token_time: 缓存token时的时间
        :return:
        """
        if all([cached_client_id, cached_token, cached_expire,
                cached_token_time]) \
                and cached_client_id == self._client_id \
                and time.time() - cached_token_time < \
                int(cached_expire) - CommonConstant\
                .REFRESH_TIME_BEFORE_EXPIRE:
            return True
        return False

    @staticmethod
    def __is_credential_valid(credential_list) -> bool:
        """
        传入的用户信息是否正确
        :param credential_list: 用户信息,包含client_id和client_secret
        :return:
        """
        return credential_list.get('client_id') and credential_list.get(
            'client_secret')



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class AlbumMetaData:
    def __init__(self):
        self._recommend_flag = None
        self._is_combined_album = None
        self._name = None
        self._remarks = None

    @property
    def remarks(self):
        """
        :return:mixed
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """
        提供给审核/运营人员查看的备注信息，不对最终用户呈现
        :param remarks:
        :return:1
        """
        self._remarks = remarks

    @property
    def recommend_flag(self):
        """
        :return:mixed
        """
        return self._recommend_flag

    @recommend_flag.setter
    def recommend_flag(self, recommend_flag):
        """
        专辑是否可推荐，为false时该专辑不在端侧展示
        :param recommend_flag:
        :return:
        """
        self._recommend_flag = recommend_flag

    @property
    def default_lang(self):
        """
        :return:mixed
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """
        缺省语言
        :param default_lang:
        :return:
        """
        self._default_lang = default_lang

    @property
    def is_combined_album(self):
        """
        :return:mixed
        """
        return self._is_combined_album

    @is_combined_album.setter
    def is_combined_album(self, is_combined_album):
        """
        是否组合专辑，为true时只能关联子专辑，不能添加课程；为false时只能关联课程不能添加子专辑
        :param is_combined_album:
        :return:
        """
        self._is_combined_album = is_combined_album

    @property
    def name(self):
        """
        :return:mxied
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        专辑默认语言名称
        :param name:
        :return:
        """
        self._name = name


# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.common.model.response import Response


class CourseStatusResponse(Response):
    """
    课程状态结果
    """
    def __init__(self):
        self._content_id = None
        self._content_version_id = None
        self._review_status = None
        self._listing_status = None
        self._reject_reason = None

    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        # 课程id
        self._content_id = content_id

    @property
    def content_version_id(self):
        return self._content_version_id

    @content_version_id.setter
    def content_version_id(self, content_version_id):
        """
        * 当前最新的课程版本ID
        * 教育中心会同时维护课程的一个在架版本和一个审核版本
        * 一个课程新建或者更新的版本审核上架后，该版本成为最新的版本
        * 一个已上架课程如果创建了新版本，该版本将成为最新版本
        :param content_version_id:
        :return:
        """
        self._content_version_id = content_version_id

    @property
    def review_status(self):
        return self._review_status

    @review_status.setter
    def review_status(self, review_status):
        """
        * 课程当前审核状态
        * 1-新建待提交：新创建课程，当前尚未提交审核
        * 2-新建待审核：新创建课程，已提交审核，当前在审核过程中
        * 3-新建审核通过：新创建课程，审核通过已处于上架状态
        * 4-新建审核驳回：新创建课程，审核未通过已被驳回
        * 5-更新待提交：课程新版本，当前尚未提交审核
        * 6-更新待审核：课程新版本，已提交审核，当前在审核过程中
        * 7-更新审核通过：课程新版本，审核通过已处于上架状态
        * 8-更新审核驳回：课程新版本，审核未通过已被驳回
        * 9-下架待审核：已提交下架申请，当前在审核过程中
        * 10-下架审核驳回：已提交下架申请，审核未通过
        * 11-运营下架：课程已被华为运营人员下架
        * 12-开发者下架审核通过：下架申请审核通过，课程已下架
        * 13-到期自动下架：设置的课程自动下架时间已到，课程被自动下架
        :param review_status:
        :return:
        """
        self._review_status = review_status

    @property
    def listing_status(self):
        return self._listing_status

    @listing_status.setter
    def listing_status(self, listing_status):
        """
        * 课程当前在架状态
        * 1-未上架: 用户无法浏览和购买课程
        * 2-已上架: 用户可正常浏览和购买课程
        :param listing_status:
        :return:
        """
        self._listing_status = listing_status

    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, reject_reason):
        """
        当reviewStatus为驳回状态时，返回运营录入的驳回原因
        :param reject_reason:
        :return:
        """
        self._reject_reason = reject_reason



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CourseEdit:
    """课程版本操作请求体"""
    def __init__(self):
        self._course_edit_id = None
        self._course = None

    @property
    def course_edit_id(self):
        """
        :return: mixed
        """
        return self._course_edit_id

    @course_edit_id.setter
    def course_edit_id(self, course_edit_id):
        """
        课程编辑版本ID
        :param course_edit_id:
        :return:
        """
        self._course_edit_id = course_edit_id

    @property
    def course(self):
        """
        :return: mixed
        """
        return self._course

    @course.setter
    def course(self, course):
        """
        课程模型
        :param course:
        :return:
        """
        self._course = course



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class UpdatePkgProductResult(Response):
    def __init__(self):
        super(UpdatePkgProductResult, self).__init__()
        self._dev_product_id = None

    @property
    def dev_product_id(self):
        return self._dev_product_id

    @dev_product_id.setter
    def dev_product_id(self, dev_product_id):
        self._dev_product_id = dev_product_id



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
import json
import logging

from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.file_upload.file_upload import FileUpload
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse
from edukit_sdk.edukit.common.model.image_file_info import ImageFileInfo
from edukit_sdk.edukit.package.model.pkg import Pkg
from edukit_sdk.edukit.package.model.pkg_localized_data import PkgLocalizedData
from edukit_sdk.edukit.package.model.products import Products
from edukit_sdk.edukit.package.resp.pkg_common_response import \
    PkgCommonResponse
from edukit_sdk.edukit.package.resp.update_pkg_product_response import \
    UpdatePkgProductResponse
from edukit_sdk.edukit.package.resp.update_pkg_product_result import \
    UpdatePkgProductResult


class PkgHandler:
    def __init__(self, request_sender: EduKitRequestSender):
        self._request_sender = request_sender

    def create_pkg(self, pkg: Pkg):
        response = PkgCommonResponse()
        url = ApiConstant.CREATE_PKG_URL
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.post(url=url, body=pkg.to_json_string()))
            response = Helpers.parse_response(
                http_common_response.get_rsp(),
                'edukit_sdk.edukit.package.resp.pkg_common_response.'
                'PkgCommonResponse'
            )
        except EduKitException as e:
            logging.error('Create package failed. ErrorMessage: %s' % str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        if response.result.result_code == CommonConstant.RESULT_SUCCESS:
            logging.info('Create package succeed, pkg_id:%s, pkg_edit_id:%s' %
                         (response.pkg_id, response.pkg_edit_id))
        else:
            logging.error('Create package failed, result:%s' %
                          response.result.to_string())
        return response

    def update_pkg(self, pkg_id, pkg: Pkg):
        response = PkgCommonResponse()
        url = ApiConstant.UPDATE_PKG_URL.format(pkg_id)
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.put(url=url, body=pkg.to_json_string()))
            response = Helpers.parse_response(
                http_common_response.get_rsp(),
                'edukit_sdk.edukit.package.resp.pkg_common_response.'
                'PkgCommonResponse'
            )
        except EduKitException as e:
            logging.error('Update package failed. ErrorMessage: %s' % str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        logging.info('Update package succeed, pkg_id:%s, pkg_edit_id:%s' %
                     (response.pkg_id, response.pkg_edit_id))
        return response

    def delete_pkg(self, pkg_id):
        logging.info('Begin to delete package %s.' % pkg_id)
        url = ApiConstant.DELETE_PKG_URL.format(pkg_id)
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.delete(url=url))
            return Helpers.build_result(http_common_response.get_rsp())
        except EduKitException as e:
            logging.error('Delete package failed. ErrorMessage: %s' % str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

    def manage(self, pkg_id, action, removal_reason):
        logging.info('Begin to manage package %s.' % pkg_id)
        url = ApiConstant.MANAGE_PKG_STATUS_URL.format(pkg_id)
        body = {"action": action, "removalReason": removal_reason}
        body = bytes(json.dumps(body), encoding=ClientConstant.UTF_8)
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.post(url=url, body=body))
            return Helpers.build_result(http_common_response.get_rsp())
        except EduKitException as e:
            logging.error('Manage package failed. ErrorMessage: %s' % str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

    def update_pkg_product(self, pkg_id, pkg_product_list: Products):
        logging.info('Begin to update package product %s.' % pkg_id)
        update_pkg_product_rsp = UpdatePkgProductResponse()
        url = ApiConstant.UPDATE_PACKAGE_PRODUCT_URL.format(pkg_id)
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=pkg_product_list.to_json_string()))
            result = http_common_response.get_rsp()
            update_pkg_product_rsp.result = Helpers.build_result(result)
        except EduKitException as e:
            logging.error('Update package product failed. ErrorMessage: %s' %
                          str(e))
            update_pkg_product_rsp.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return update_pkg_product_rsp

        if result['result']['resultCode'] != CommonConstant.RESULT_SUCCESS:
            return update_pkg_product_rsp

        details = list()
        for update_result in result['PkgProductUpdateResults']:
            update_pkg_product_result = UpdatePkgProductResult()
            update_pkg_product_result.dev_product_id = update_result[
                'devProductId']
            update_pkg_product_result.result = Helpers.build_result(
                update_result)
            details.append(update_pkg_product_result)

        update_pkg_product_rsp.details = details
        return update_pkg_product_rsp

    def delete(self, pkg_id, pkg_edit_id, product_id):
        logging.info(
            'Begin to delete package product, pdg_id:%s, pkg_edit_id:%s, '
            'product_id:%s.'
            % (pkg_id, pkg_edit_id, product_id))
        url = ApiConstant.DELETE_PACKAGE_PRODUCT_URL.format(
            pkg_id, pkg_edit_id, product_id)
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.delete(url=url))
            return Helpers.build_result(http_common_response.get_rsp())
        except EduKitException as e:
            logging.error('Delete package product failed. ErrorMessage: %s' %
                          str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

    def covert_localized_datas(self, pkg: Pkg):
        if not pkg.edit or not pkg.edit.localized_data:
            return

        for localized_data in pkg.edit.localized_data:
            result = self._covert_localized_data(localized_data)
            if not result:
                return

    def _covert_localized_data(self, localized_data: PkgLocalizedData):
        if localized_data.cover_image_info:
            upload_result = self._upload_image(localized_data.cover_image_info)
            if not upload_result:
                return False
            localized_data.cover_image_id = upload_result

        if not localized_data.introduce_infos:
            return

        introduce_ids = list()
        for introduce_info in localized_data.introduce_infos:
            upload_result = self._upload_image(introduce_info)
            if not upload_result:
                return False
            introduce_ids.append(upload_result)
        localized_data.introduce_ids = introduce_ids

    def _upload_image(self, image: ImageFileInfo):
        try:
            file_upload = FileUpload(path=image.path,
                                     resource_type=image.resource_type,
                                     request_sender=self._request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload image:%s failed. ErrorMessage: %s' %
                          (image.path, str(e)))
            return False
        if not Helpers.is_success(result):
            logging.error('Upload image:%s failed. errMsg: %s' %
                          (image.path, result['result']['resultDesc']))
            return False

        return result['materialId']



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class Response:
    def __init__(self):
        self._result = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, result):
        self._result = result



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class AbstractErrorCode:
    @staticmethod
    def get_service_code():
        """
        获取服务编码，前4位
        :return:String 服务编码
        """
        return 0x3823

    def get_resp_error_code(self):
        """
        获取完整的错误码，高4位业务编码拼上低4位业务错误码
        :return: int 完整错误码
        """
        error_code = getattr(self, 'error_code')
        return (self.get_service_code() << 16) + error_code

    def get_hex_format_code(self):
        """
        获取完整的错误码的16进制编码输出
        :return:String 完整错误码
        """
        return hex(self.get_resp_error_code())

    def get_message(self):
        """
        获取错误描述信息，错误码+错误描述
        :return:String 描述信息
        """
        method = getattr(self, 'get_error_desc')
        return ''.join([self.get_hex_format_code(), ": ", ": ", method()])



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
import json
import logging

from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.errorcode.teacher_error_code import \
    TeacherErrorCode
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.file_upload.file_upload import FileUpload
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse
from edukit_sdk.edukit.common.model.image_file_info import ImageFileInfo
from edukit_sdk.edukit.teacher.impl.teacher_commit_request import \
    TeacherCommitRequest
from edukit_sdk.edukit.teacher.impl.teacher_create_result import \
    TeacherCreateResult
from edukit_sdk.edukit.teacher.impl.teacher_update_localized_data_request \
    import TeacherUpdateLocalizedDataRequest
from edukit_sdk.edukit.teacher.model.teacher import Teacher
from edukit_sdk.edukit.teacher.model.teacher_basic_info import TeacherBasicInfo
from edukit_sdk.edukit.teacher.model.teacher_edit import TeacherEdit
from edukit_sdk.edukit.teacher.model.teacher_localized_data import \
    TeacherLocalizedData
from edukit_sdk.edukit.teacher.resp.teacher_update_response import \
    TeacherUpdateResponse


class TeacherHandler:
    def __init__(self, request_sender: EduKitRequestSender):
        self._request_sender = request_sender

    def create_teacher(self, teacher: Teacher):
        response = TeacherCreateResult()
        if not teacher:
            response.result = Helpers.build_error_result(
                TeacherErrorCode.INVALID_TEACHER_PARAMS_TEACHER)
            return response

        if not teacher.dev_teacher_id:
            response.result = Helpers.build_error_result(
                TeacherErrorCode.INVALID_TEACHER_PARAMS_DEV_TEACHER_ID)
            return response
        logging.info('Begin to create teacher!')

        teacher_basic_info = TeacherBasicInfo()
        teacher_basic_info.dev_teacher_id = teacher.dev_teacher_id

        url = ApiConstant.CREATE_TEACHER_URL
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.post(
                    url=url, body=teacher_basic_info.to_json_string()))
            response = Helpers.parse_response(
                http_common_response.get_rsp(),
                'edukit_sdk.edukit.teacher.impl.teacher_create_result.'
                'TeacherCreateResult'
            )
        except EduKitException as e:
            logging.error(
                'Call create teacher interface failed. ErrorMessage: %s' %
                str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        return response

    def update_teacher(self, teacher: Teacher,
                       teacher_create_result: TeacherCreateResult):
        response = TeacherUpdateResponse()
        if teacher.teacher_metadata:
            response.update_metadata_result = self._update_metadata(
                teacher, teacher_create_result)
            if response.update_metadata_result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                return response

        if teacher.teacher_multi_language_data_list:
            response.update_localized_data_result = \
                self._update_localized_data_list(
                    teacher.teacher_multi_language_data_list,
                    teacher_create_result)
            if response.update_localized_data_result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                return response

        if teacher.language_list_to_delete:
            response.delete_localized_data_result = \
                self._delete_localized_data(
                    teacher.language_list_to_delete,
                    teacher_create_result.teacher_id,
                    teacher_create_result.edit_id)

        return response

    def commit(self, teacher_id, edit_id):
        logging.info('Begin to commit teacher,teacher_id:%s, edit_id:%s' %
                     (teacher_id, edit_id))
        teacher_commit_request = TeacherCommitRequest()
        teacher_commit_request.teacher_id = teacher_id
        teacher_commit_request.edit_id = edit_id
        url = ApiConstant.COMMIT_TEACHER_URL
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.post(
                    url=url, body=teacher_commit_request.to_json_string()))
        except EduKitException as e:
            logging.error('Commit teacher failed. ErrorMessage: %s' % str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        return Helpers.build_result(http_common_response.get_rsp())

    def update_teacher_basic_info(self, teacher_id, dev_teacher_id):
        logging.info(
            'Begin to update teacher basic info, teacher_id:%s, '
            'dev_teacher_id:%s'
            % (teacher_id, dev_teacher_id))
        headers = dict()
        if teacher_id:
            headers['teacherId'] = teacher_id
        teacher_basic_info = TeacherBasicInfo()
        teacher_basic_info.dev_teacher_id = dev_teacher_id
        url = ApiConstant.CREATE_TEACHER_URL
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url,
                    body=teacher_basic_info.to_json_string(),
                    headers=headers))
        except EduKitException as e:
            logging.error(
                'Update teacher basic info failed. ErrorMessage: %s' % str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        return Helpers.build_result(http_common_response.get_rsp())

    def create_teacher_edit(self, teacher_edit: TeacherEdit):
        teacher_id = '' if not teacher_edit \
                           or not teacher_edit.teacher \
                           or not teacher_edit.teacher.teacher_id \
                           else teacher_edit.teacher.teacher_id
        dev_teacher_id = '' if not teacher_edit or not \
            teacher_edit.teacher or not teacher_edit.teacher.dev_teacher_id \
            else teacher_edit.teacher.dev_teacher_id
        logging.info(
            'Begin to create new teacher edit, teacher_id:%s, '
            'dev_teacher_id:%s.'
            % (teacher_id, dev_teacher_id))
        rsp = TeacherUpdateResponse()
        headers = dict()
        headers['teacherId'] = teacher_id
        if dev_teacher_id:
            headers['devTeacherId'] = dev_teacher_id
        url = ApiConstant.CREATE_NEW_TEACHER_EDIT_URL
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.post(url=url, headers=headers))
        except EduKitException as e:
            logging.error(
                'Create new teacher edit failed, teacher_id:%s. '
                'ErrorMessage: %s'
                % (teacher_id, str(e)))
            rsp.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return rsp
        rsp.teacher_id = teacher_id

        rsp.result = Helpers.build_result(http_common_response.get_rsp())
        if rsp.result.result_code != CommonConstant.RESULT_SUCCESS:
            logging.error(
                'create teacher edit failed! result_code: %s, result_desc: %s'
                % (rsp.result.result_code, rsp.result.result_desc))
        else:
            rsp.teacher_edit_id = http_common_response.get_rsp()['editId']
        return rsp

    def delete(self, teacher_id, reason):
        if not teacher_id:
            return Helpers.build_error_result(
                TeacherErrorCode.INVALID_TEACHER_PARAMS_TEACHER_ID)

        url = ApiConstant.DELETE_TEACHER_URL.format(teacher_id)
        body = {"reason": reason}
        body = bytes(json.dumps(body), encoding='utf-8')
        try:
            http_common_response = HttpCommonResponse(
                self._request_sender.post(url=url, body=body))
        except EduKitException as e:
            logging.error(
                'Delete teacher failed, teacher_id:%s. ErrorMessage: %s' %
                (teacher_id, str(e)))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        return Helpers.build_result(http_common_response.get_rsp())

    def _update_metadata(self, teacher: Teacher,
                         teacher_create_result: TeacherCreateResult):
        dev_teacher_id = teacher.dev_teacher_id
        teacher_id = teacher_create_result.teacher_id
        teacher_edit_id = teacher_create_result.edit_id
        if not teacher_id:
            teacher_id = dev_teacher_id
        logging.info(
            'Begin to update teacher metadata, teacherId: %s, teacherEditId:%s'
            % (teacher_id, teacher_edit_id))
        try:
            url = ApiConstant.UPDATE_META_TEACHER_URL.format(
                teacher_id, teacher_edit_id)
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=teacher.teacher_metadata.to_json_string()))
        except EduKitException as e:
            logging.error(
                'Call update teacher metadata interface failed. '
                'ErrorMessage: %s'
                % str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        return Helpers.build_result(http_common_response.get_rsp())

    def _update_localized_data_list(
            self, teacher_multi_language_data_list,
            teacher_create_result: TeacherCreateResult):
        response = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        teacher_id = teacher_create_result.teacher_id
        teacher_edit_id = teacher_create_result.edit_id
        logging.info(
            'Begin to update teacher localized data, teacherId: %s, '
            'teacherEditId:%s'
            % (teacher_id, teacher_edit_id))
        for teacher_multi_language_data in teacher_multi_language_data_list:
            if teacher_multi_language_data.teacher_portrait:
                upload_result = self._upload_portrait(
                    teacher_multi_language_data.teacher_portrait)
                if not upload_result:
                    response = Helpers.build_error_result(
                        CommonErrorCode.UPLOAD_FILES_FAILED)
                    break
                teacher_multi_language_data.portrait_id = upload_result

            update_localized_data_result = self._update_localized_data(
                teacher_multi_language_data, teacher_id, teacher_edit_id,
                teacher_multi_language_data.language)
            if update_localized_data_result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                response = update_localized_data_result
                break
        return response

    def _update_localized_data(
            self, teacher_multi_language_data: TeacherLocalizedData,
            teacher_id, teacher_edit_id, language):
        update_localized_data_request = TeacherUpdateLocalizedDataRequest()
        update_localized_data_request.localized_data = \
            teacher_multi_language_data
        try:
            url = ApiConstant.UPDATE_LOCALIZED_TEACHER_URL.format(
                teacher_id, teacher_edit_id, language)
            http_common_response = HttpCommonResponse(
                self._request_sender.put(
                    url=url,
                    body=update_localized_data_request.to_json_string()))
        except EduKitException as e:
            logging.error(
                'Update teacher localized data failed. ErrorMessage: %s' %
                str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        return Helpers.build_result(http_common_response.get_rsp())

    def _delete_localized_data(self, language_list, teacher_id,
                               teacher_edit_id):
        response = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        logging.info(
            'Begin to delete teacher localized data, teacherId: %s, '
            'teacherEditId:%s'
            % (teacher_id, teacher_edit_id))
        for language in language_list:
            url = ApiConstant.DELETE_LOCALIZED_TEACHER_URL.format(
                teacher_id, teacher_edit_id, language)
            try:
                http_common_response = HttpCommonResponse(
                    self._request_sender.delete(url=url))
            except EduKitException as e:
                logging.error(
                    'Delete teacher localized data failed. ErrorMessage: %s' %
                    str(e))
                return Helpers.build_error_result(
                    CommonErrorCode.CALL_API_INTERFACE_FAILED)

            if not Helpers.is_success(http_common_response.get_rsp()):
                response = Helpers.build_result(http_common_response.get_rsp())
                break
        return response

    def _upload_portrait(self, portrait: ImageFileInfo):
        try:
            file_upload = FileUpload(path=portrait.path,
                                     resource_type=portrait.resource_type,
                                     request_sender=self._request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload teacher portrait failed. ErrorMessage: %s' %
                          str(e))
            return False
        if not Helpers.is_success(result):
            logging.error('Upload teacher portrait failed. errMsg: %s' %
                          result['result']['resultDesc'])
            return False

        return result['materialId']



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class TeacherUpdateLocalizedDataRequest:
    def __init__(self):
        self._localized_data = None,

    @property
    def localized_data(self):
        return self._localized_data

    @localized_data.setter
    def localized_data(self, localized_data):
        self._localized_data = localized_data

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import hashlib
import importlib
import logging
import mimetypes
import os

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.model.result import Result


class Helpers:
    @staticmethod
    def get_root():
        return os.path.join(os.getcwd(), '..', '..', '..', '..')

    @staticmethod
    def get_file_dir_name(path):
        path = path if path else ''
        return os.path.split(path)[0]

    @staticmethod
    def get_file_base_name(path):
        path = path if path else ''
        return os.path.split(path)[1]

    @staticmethod
    def get_file_name(path):
        path = path if path else ''
        return os.path.splitext(Helpers.get_file_base_name(path))[0]

    @staticmethod
    def get_file_extension(path):
        path = path if path else ''
        return os.path.splitext(Helpers.get_file_base_name(path))[1]

    @staticmethod
    def get_file_size(path):
        return os.path.getsize(path)

    @staticmethod
    def get_sha256(path):
        h = hashlib.sha256()
        with open(path, 'rb') as file:
            chunk = 0
            while chunk != b'':
                # read only 1024 bytes at a time
                chunk = file.read(1024)
                h.update(chunk)

        # 返回摘要的十六进制表示
        return h.hexdigest()

    @staticmethod
    def get_mime(path):
        return mimetypes.guess_type(path)[0]

    @staticmethod
    def build_error_result(errcode):
        result = Result()
        common_error_code = CommonErrorCode(errcode)
        result.result_code = common_error_code.get_resp_error_code()
        result.result_desc = common_error_code.error_desc
        return result

    @staticmethod
    def change_object_to_array(obj):
        object_to_array_list = dict()
        if vars(obj).items():
            for name, value in vars(obj).items():
                method_value_list = list()
                if isinstance(value, list):
                    for item in value:
                        if hasattr(item, '__dict__'):
                            method_value_list.append(
                                Helpers.change_object_to_array(item))
                        else:
                            method_value_list.append(item)
                else:
                    if hasattr(value, '__dict__'):
                        method_value_list.append(
                            Helpers.change_object_to_array(value))
                    else:
                        method_value_list.append(value)
                server_name = Helpers.change_to_server_name(name)
                if isinstance(value, list):
                    object_to_array_list[server_name] = method_value_list
                else:
                    object_to_array_list[server_name] = method_value_list[0] \
                        if len(method_value_list) == 1 else method_value_list

        return object_to_array_list

    @staticmethod
    def parse_response(response, obj_name: str):
        path, class_name = str(obj_name).rsplit('.', 1)
        package = importlib.import_module(path)
        method = getattr(package, class_name)
        obj = method()
        if obj:
            property_name_list = [
                k[1:] if k[:1] == '_' else k for k in obj.__dict__.keys()
            ]
        if response:
            logging.info(response)
            for k, v in response.items():
                Helpers.set_attr(k, v, property_name_list, obj)
        return obj

    @staticmethod
    def is_success(result):
        result_code = result.get('result').get('resultCode')
        return True if result_code is not None and \
                       result_code == CommonConstant.RESULT_SUCCESS else False

    @staticmethod
    def build_result(rsp):
        logging.info(rsp)
        result = rsp.get('result')
        result_obj = Result()
        result_obj.result_code = result.get('resultCode')
        result_obj.result_desc = result.get('resultDesc')
        return result_obj

    @staticmethod
    def has_empty_param(param):
        for item in param:
            if not item:
                return True
        return False

    @staticmethod
    def set_attr(name, value, property_name_list, obj):
        if name != 'result':
            for item in property_name_list:
                if item.replace('_', '').lower() == name.lower():
                    setattr(obj, item, value)
        else:
            result = Result()
            result.result_code = value.get('resultCode')
            result.result_desc = value.get('resultDesc')
            setattr(obj, 'result', result)

    @staticmethod
    def change_to_server_name(name: str):
        server_name = ''
        if name:
            name_list = name.split('_')
            for item in name_list:
                if server_name:
                    server_name += item.capitalize()
                else:
                    server_name += item
        return server_name



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.teacher.model.teacher_metadata import TeacherMetaData


class Teacher:
    def __init__(self):
        self._teacher_id = None
        self._dev_teacher_id = None
        self._teacher_metadata = None
        self._teacher_multi_language_data_list = None
        self._language_list_to_delete = None

    @property
    def teacher_id(self):
        """
        :return: mixed
        """
        return self._teacher_id

    @teacher_id.setter
    def teacher_id(self, teacher_id):
        """
        教师ID,通过addTeacher接口返回
        :param teacher_id:
        :return:
        """
        self._teacher_id = teacher_id

    @property
    def dev_teacher_id(self):
        """
        :return: mixed
        """
        return self._dev_teacher_id

    @dev_teacher_id.setter
    def dev_teacher_id(self, dev_teacher_id):
        """
        教师编号初值或待更新值，由开发者指定
        :param dev_teacher_id:
        :return:
        """
        self._dev_teacher_id = dev_teacher_id

    @property
    def teacher_metadata(self):
        """
        :return: mixed
        """
        return self._teacher_metadata

    @teacher_metadata.setter
    def teacher_metadata(self, teacher_metadata: TeacherMetaData):
        """
        教师元数据，
        包含两个字段，famousFlag和defaultLang。
        您必须提供默认语言对应的教师信息
        此字段在教师信息首次提交审核时必须指定，否则将返回错误；后续更新时可不携带，此时将保持当前取值不变
        :param teacher_metadata:
        :return:
        """
        self._teacher_metadata = teacher_metadata

    @property
    def teacher_multi_language_data_list(self):
        """
        :return: mixed
        """
        return self._teacher_multi_language_data_list

    @teacher_multi_language_data_list.setter
    def teacher_multi_language_data_list(self,
                                         teacher_multi_language_data_list):
        """
        教师本地多语言数据(详见TeacherMultiLangLocalizedData类)的List
        :param teacher_multi_language_data_list:
        :return:
        """
        self._teacher_multi_language_data_list = \
            teacher_multi_language_data_list

    @property
    def language_list_to_delete(self):
        """
        :return: mixed
        """
        return self._language_list_to_delete

    @language_list_to_delete.setter
    def language_list_to_delete(self, language_list_to_delete):
        """
        待删除本地化多语言数据语言的List
        :param language_list_to_delete:
        :return:
        """
        self._language_list_to_delete = language_list_to_delete



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CatalogueFullLocalizedData:
    def __init__(self):
        self._name = None
        self._language = None

    @property
    def name(self):
        """
        :return: mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        目录名称
        :param name:
        :return:
        """
        self._name = name

    @property
    def language(self):
        """
        :return: mixed
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        语言代码
        :param language:
        :return:
        """
        self._language = language



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.errorcode.teacher_error_code import \
    TeacherErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.teacher.impl.teacher_create_result import \
    TeacherCreateResult
from edukit_sdk.edukit.teacher.impl.teacher_handler import TeacherHandler
from edukit_sdk.edukit.teacher.model.teacher import Teacher
from edukit_sdk.edukit.teacher.model.teacher_edit import TeacherEdit
from edukit_sdk.edukit.teacher.resp.teacher_update_response import \
    TeacherUpdateResponse


class TeacherUpdateRequest:
    def __init__(self, teacher_edit: TeacherEdit, credential_list):
        self._teacher_edit = teacher_edit
        self._teacher_handler = TeacherHandler(
            EduKitRequestSender(credential_list))

    def save_draft(self):
        teacher_update_rsp = TeacherUpdateResponse()
        logging.info('Update teacher begin')
        if not self._teacher_edit or not self._teacher_edit.teacher \
                or not self._teacher_edit.teacher.teacher_id:
            logging.error('Teacher_id can not be null when updating teacher.')
            teacher_update_rsp.result = Helpers.build_error_result(
                TeacherErrorCode.INVALID_TEACHER_PARAMS_TEACHER_ID)
            return teacher_update_rsp

        dev_teacher_id = '' if not self._teacher_edit or not \
            self._teacher_edit.teacher or not \
            self._teacher_edit.teacher.dev_teacher_id else \
            self._teacher_edit.teacher.dev_teacher_id

        self.__update_teacher_edit(self._teacher_edit.teacher,
                                   self._teacher_edit.teacher.teacher_id,
                                   dev_teacher_id, teacher_update_rsp)

        return teacher_update_rsp

    def commit(self):
        teacher_update_rsp = self.save_draft()
        if teacher_update_rsp.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            return teacher_update_rsp

        commit_result = self._teacher_handler.commit(
            self._teacher_edit.teacher.teacher_id,
            teacher_update_rsp.teacher_edit_id)
        teacher_update_rsp.teacher_commit_result = commit_result
        if commit_result.result_code != CommonConstant.RESULT_SUCCESS:
            teacher_update_rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARTIAL_SUCCESS)
        else:
            teacher_update_rsp.result = Helpers.build_error_result(
                CommonErrorCode.SUCCESS)

        return teacher_update_rsp

    def __update_teacher_edit(self, teacher: Teacher, teacher_id,
                              dev_teacher_id, rsp: TeacherUpdateResponse):
        if dev_teacher_id:
            update_basic_info_result = \
                self._teacher_handler.update_teacher_basic_info(
                    teacher_id,
                    dev_teacher_id)
            rsp.update_basic_info_result = update_basic_info_result
            if update_basic_info_result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.NO_SUCCESSFUL_OPERATION)
                return False

        if self.__need_create_new_edit(teacher):
            new_edit = self._teacher_handler.create_teacher_edit(
                self._teacher_edit)
            rsp.create_new_edit_result = new_edit.result
            if new_edit.result.result_code != CommonConstant.RESULT_SUCCESS:
                rsp.result = Helpers.build_error_result(
                    CommonErrorCode.NO_SUCCESSFUL_OPERATION)
                return rsp
            edit_id = new_edit.teacher_edit_id
        else:
            edit_id = self._teacher_edit.teacher_edit_id

        rsp.teacher_edit_id = edit_id
        teacher_create_result = TeacherCreateResult()
        teacher_create_result.teacher_id = teacher_id
        teacher_create_result.edit_id = edit_id
        update_rsp = self._teacher_handler.update_teacher(
            teacher, teacher_create_result)
        rsp.update_metadata_result = update_rsp.update_metadata_result
        rsp.update_localized_data_result = \
            update_rsp.update_localized_data_result
        rsp.delete_localized_data_result = \
            update_rsp.delete_localized_data_result
        if self.__is_update_success(update_rsp):
            rsp.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
        else:
            rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARTIAL_SUCCESS)
        return rsp

    @staticmethod
    def __is_update_success(update_rsp: TeacherUpdateResponse):
        if update_rsp.update_metadata_result and \
                update_rsp.update_metadata_result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            return False
        if update_rsp.update_localized_data_result and \
                update_rsp.update_localized_data_result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            return False
        if update_rsp.delete_localized_data_result and \
                update_rsp.delete_localized_data_result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            return False

        return True

    def __need_create_new_edit(self, teacher: Teacher):
        return True if not self._teacher_edit.teacher_edit_id and (
                    teacher.teacher_multi_language_data_list
                    or teacher.teacher_metadata
                    or teacher.language_list_to_delete) \
            else False



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class LessonUpdateResponse(Response):
    def __init__(self):
        self._lesson_id = None
        self._lesson_edit_id = None
        self._update_lesson_meta_data_result = None
        self._update_localized_data_result = None
        self._delete_localized_data_result = None
        self._result = None
        super(LessonUpdateResponse, self).__init__()

    @property
    def lesson_id(self):
        """
        :return:mixed
        """
        return self._lesson_id

    @lesson_id.setter
    def lesson_id(self, lesson_id):
        """
        :param lesson_id:
        """
        self._lesson_id = lesson_id

    @property
    def update_lesson_meta_data_result(self):
        """
        :return:mixed
        """
        return self._update_lesson_meta_data_result

    @update_lesson_meta_data_result.setter
    def update_lesson_meta_data_result(self, update_lesson_meta_data_result):
        """
        :param update_lesson_meta_data_result:
        """
        self._update_lesson_meta_data_result = update_lesson_meta_data_result

    @property
    def update_localized_data_result(self):
        """
        :return:mixed
        """
        return self._update_localized_data_result

    @update_localized_data_result.setter
    def update_localized_data_result(self, update_localized_data_result):
        """
        :param update_localized_data_result:
        """
        self._update_localized_data_result = update_localized_data_result

    @property
    def lesson_edit_id(self):
        """
        :return:mixed
        """
        return self._lesson_edit_id

    @lesson_edit_id.setter
    def lesson_edit_id(self, lesson_edit_id):
        """
        :param lesson_edit_id:
        """
        self._lesson_edit_id = lesson_edit_id

    @property
    def delete_localized_data_result(self):
        """
        :return:mixed
        """
        return self._delete_localized_data_result

    @delete_localized_data_result.setter
    def delete_localized_data_result(self, delete_localized_data_result):
        """
        :param delete_localized_data_result:
        """
        self._delete_localized_data_result = delete_localized_data_result



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class UpdateEditLocalizedData:
    def __init__(self):
        self._name = None  # 课程名称
        self._short_description = None  # 课程简要介绍
        self._full_description = None  # 课程详细介绍
        self._cover_id = None  # 横版封面图片的文件的素材id
        self._portrait_cover_id = None  # 竖版封面图片的文件的素材id
        self._introduce_ids = None  # 课程介绍图片文件的素材id列表
        self._deeplink_url = None  # 从教育中心App跳转到您的App的DeepLink链接

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, name):
        self._name = name

    @property
    def cover_id(self):
        return self._cover_id

    @cover_id.setter
    def cover_id(self, cover_id):
        self._cover_id = cover_id

    @property
    def short_description(self):
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        self._short_description = short_description

    @property
    def portrait_cover_id(self):
        return self._portrait_cover_id

    @portrait_cover_id.setter
    def portrait_cover_id(self, portrait_cover_id):
        self._portrait_cover_id = portrait_cover_id

    @property
    def introduce_ids(self):
        return self._introduce_ids

    @introduce_ids.setter
    def introduce_ids(self, introduce_ids):
        self._introduce_ids = introduce_ids

    @property
    def deeplink_url(self):
        return self._deeplink_url

    @deeplink_url.setter
    def deeplink_url(self, deeplink_url):
        self._deeplink_url = deeplink_url

    @property
    def full_description(self):
        return self._full_description

    @full_description.setter
    def full_description(self, full_description):
        self._full_description = full_description




#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ServiceErrorCode:
    def __init__(self, success=0, success_desc: str = "Operation success"):
        self.success = success
        self.success_desc = success_desc

    @staticmethod
    def get_error_code(self):
        """
        * 获取错误编码，后4位
        :return: 错误编码
        """
        pass

    @staticmethod
    def get_error_desc(self):
        """
        * 获取错误描述
        :return: 错误描述
        """
        pass



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import os


class FileUploadConstant:
    """
     资源文件类型，当前支持如下类型。上传时必须指定此字段以匹配校验规则：
     * 1--课程/会员包/专辑横版封面图片, (宽高)1280720像素，PNG/JPG格式，小于2MBytes
     * 2--宣传视频海报, (宽高)1280720像素，PNG/JPG格式, 小于2MBytes
     * 3--课程/会员包介绍图片, 宽1080像素，高度任意但不超过4096像素，PNG/JPG格式, 小于2MBytes
     * 4--教师头像, (宽高)312312像素，PNG/JPG格式, 小于0.5MBytes
     * 5--课程竖版封面图片, (宽高)405540像素，PNG/JPG格式，小于2MBytes
     * 6--专辑竖版封面图片，(宽高)1080360像素，PNG/JPG格式，小于2MBytes
    """
    RESOURCE_TYPE = {
        'COURSE_PACKAGE_HORIZONTAL_COVER': 1,
        'PROMOTIONAL_VIDEO_POSTER': 2,
        'COURSE_PACKAGE_INTRODUCTION': 3,
        'TUTOR_PORTRAIT': 4,
        'COURSE_PORTRAIT_COVER': 5,
        'ALBUM_LANDSCAPE_COVER': 6
    }

    MEDIA_FILE_TYPE = {
        'MP3': "audio/mp3",
        'WAV': "audio/wav",
        'MP4': "video/mp4",
        'MOV': "video/mov"
    }

    UPLOAD_FAILED = 'Upload failed! ErrorMessage:{}'

    # 允许上传的图片格式
    PICTURE_SUFFIX = ['.jpg', '.png']

    # 允许上传的媒体文件格式
    FILE_SUFFIX = ['.mp3', '.wav', '.mp4', '.mov']

    # 文件缓存目录
    FILE_CACHE_DIR = os.sep + 'storage' + os.sep + 'cache' + os.sep

    # 默认分片文件大小
    DEFAULT_PART_SIZE = 52428800

    # 特殊目录名
    DIR_POINT = '.'
    DIR_DUBLE_POINT = '..'

    # 相对路径正则
    RELATIVE_PATH_PATTERN = \
        '/\.\/|\.\.\/|%|\%00|\.\\\.\\\|\.\\\./'
    FILE_UPLOAD_LIMIT_TIME = 600



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class Result:
    def __init__(self):
        self._result_code = None
        self._result_desc = None

    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, result_code):
        self._result_code = result_code

    @property
    def result_desc(self):
        return self._result_desc

    @result_desc.setter
    def result_desc(self, result_desc):
        self._result_desc = result_desc

    def to_string(self):
        result_code = '' if not self._result_code and self._result_code != 0 \
            else str(self._result_code)
        result_desc = '' if not self._result_desc else self._result_desc
        return '{"resultCode":' + result_code + \
               ', "resultDesc":"' + result_desc + '"}'



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.auth.auth_token_credential import \
    AuthTokenCredential
from edukit_sdk.edukit.common.config.config import Config
from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.http_constant import HttpConstant
from edukit_sdk.edukit.common.http.client import Client
from edukit_sdk.edukit.common.http.request import Request


class EduKitRequestSender:
    def __init__(self, credential_list: dict):
        self._client = Client()
        config = Config()
        self._agent = config.get_config().get(
            ClientConstant.SDK_NAME) + '-' + config.get_config().get(
                ClientConstant.SDK_VERSION)
        self._domain = config.get_domain()
        self._credential_list = credential_list
        self._log_info_prefix = ClientConstant.REQUESTING

    def post(self, url, body=None, headers=None, form_data=None, params=None):
        """
        post请求
        :param url: 请求url
        :param body: 请求体
        :param headers: 请求头,如果传入为空,则默认为是application/json
        :param form_data: 非文件数据
        :param params:
        :return:
        """
        request = self.build_request(method=HttpConstant.REQUEST_METHOD_POST,
                                     headers=headers,
                                     url=url,
                                     body=body,
                                     form_data=form_data,
                                     params=params)
        logging.info(self._log_info_prefix + request.url)
        return self._client.send_request(request)

    def put(self, url, body=None, headers=None):
        request = self.build_request(method=HttpConstant.REQUEST_METHOD_PUT,
                                     headers=headers,
                                     url=url,
                                     body=body)
        logging.info(self._log_info_prefix + request.url)
        return self._client.send_request(request)

    def get(self, url, headers=None, body=None, params=None):
        request = self.build_request(method=HttpConstant.REQUEST_METHOD_GET,
                                     headers=headers,
                                     url=url,
                                     body=body,
                                     form_data=None,
                                     params=params)
        logging.info(self._log_info_prefix + request.url)
        return self._client.send_request(request)

    def delete(self, url, headers=None, body=None):
        request = self.build_request(method=HttpConstant.REQUEST_METHOD_DELETE,
                                     headers=headers,
                                     url=url,
                                     body=body)
        logging.info(self._log_info_prefix + request.url)
        return self._client.send_request(request)

    def upload_once(self, url, headers, body, method):
        return self._client.send_request(
            Request(url=url, method=method, headers=headers, body=body))

    def build_request(self,
                      method,
                      headers,
                      url,
                      body,
                      form_data=None,
                      params=None):
        """
        @param method 请求方法
        @param headers 请求头,如果传入为None,则返回为application/json
        @param url 请求url
        @param body 请求体(如果是上传文件,包含要传入的二进制数据)
        @param form_data 非文件数据
        @param params
        @return Request
        """
        auth_token_credential = AuthTokenCredential(self._credential_list)
        token = auth_token_credential.get_token()
        if not headers:
            headers = dict()
        headers[HttpConstant.HEAD_AUTHORIZATION] = 'Bearer ' + token
        headers[HttpConstant.
                HEAD_CLIENT_ID] = auth_token_credential.get_client_id()
        headers[HttpConstant.HEAD_USER_AGENT] = self._agent
        if not headers.get(HttpConstant.CONTENT_TYPE):
            headers[HttpConstant.CONTENT_TYPE] = HttpConstant.APPLICATION_JSON
        url = self._domain + url

        return Request(url, method, headers, body, form_data, params)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CourseEditMetaData:
    def __init__(self):
        self._validity_num = None
        self._default_lang = None
        self._category_ids = None
        self._tag_ids = None
        self._resident_a_g_app = None
        self._source_name = None
        self._selling_mode = None
        self._remarks = None
        self._available_from = None
        self._available_before = None
        self._name = None
        self._auto_status_change = None
        self._eduapp_used = None
        self._eduapp_purchased = None
        self._dev_product_id = None
        self._dist_notify_url = None
        self._validity_unit = None
        self._include_lessons = None
        self._type_id = None
        self._teachers = None
        self._need_delivery = None
        self._media_type = None
        self._refund_notify_url = None

    @property
    def auto_status_change(self):
        """
        :return: mixed
        """
        return self._auto_status_change

    @auto_status_change.setter
    def auto_status_change(self, auto_status_change):
        """
        自动状态变更设置
        :param auto_status_change:
        :return:
        """
        self._auto_status_change = auto_status_change

    @property
    def default_lang(self):
        """
        :return: mixed
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """
        课程的默认语言代码
        :param default_lang:
        :return:
        """
        self._default_lang = default_lang

    @property
    def available_before(self):
        """
        :return: mixed
        """
        return self._available_before

    @available_before.setter
    def available_before(self, available_before):
        """
        课程最晚可用时间
        :param available_before:
        :return:
        """
        self._available_before = available_before

    @property
    def available_from(self):
        """
        :return: mixed
        """
        return self._available_from

    @available_from.setter
    def available_from(self, available_from):
        """
        课程最早可用时间
        :param available_from:
        :return:
        """
        self._available_from = available_from

    @property
    def category_ids(self):
        """
        :return: mixed
        """
        return self._category_ids

    @category_ids.setter
    def category_ids(self, category_ids):
        """
        课程三级分类ID列表，请参见课程分类ID
        :param category_ids:
        :return:
        """
        self._category_ids = category_ids

    @property
    def dist_notify_url(self):
        """
        :return: mixed
        """
        return self._dist_notify_url

    @dist_notify_url.setter
    def dist_notify_url(self, dist_notify_url):
        """
        用户直购课程的发货通知地址(HTTPS URL)
        :param dist_notify_url:
        :return:
        """
        self._dist_notify_url = dist_notify_url

    @property
    def eduapp_purchased(self):
        """
        :return: mixed
        """
        return self._eduapp_purchased

    @eduapp_purchased.setter
    def eduapp_purchased(self, eduapp_purchased):
        """
        课程是否支持直接在教育中心App购买
        :param eduapp_purchased:
        :return:
        """
        self._eduapp_purchased = eduapp_purchased

    @property
    def eduapp_used(self):
        """
        :return: mixed
        """
        return self._eduapp_used

    @eduapp_used.setter
    def eduapp_used(self, eduapp_used):
        """
        课程是否支持在教育中心学习
        :param eduapp_used:
        :return:
        """
        self._eduapp_used = eduapp_used

    @property
    def include_lessons(self):
        """
        :return: mixed
        """
        return self._include_lessons

    @include_lessons.setter
    def include_lessons(self, include_lessons):
        """
        本课程是否包含章节
        :param include_lessons:
        :return:
        """
        self._include_lessons = include_lessons

    @property
    def name(self):
        """
        :return: mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        默认语言（见defaultLang字段说明）对应的课程名称
        :param name:
        :return:
        """
        self._name = name

    @property
    def remarks(self):
        """
        :return: mixed
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """
        提供给审核/运营人员查看的备注信息
        :param remarks:
        :return:
        """
        self._remarks = remarks

    @property
    def resident_a_g_app(self):
        """
        :return: mixed
        """
        return self._resident_a_g_app

    @resident_a_g_app.setter
    def resident_a_g_app(self, resident_a_g_app):
        """
        该课程所属应用在华为应用市场的AppID
        :param resident_a_g_app:
        :return:
        """
        self._resident_a_g_app = resident_a_g_app

    @property
    def selling_mode(self):
        """
        :return: mixed
        """
        return self._selling_mode

    @selling_mode.setter
    def selling_mode(self, selling_mode):
        """
        课程售卖模式，说明如下：
        支持如下取值：
        0：单课程售卖
        1：免费
        2：仅支持会员包售卖
        3：同时支持单课程售卖和会员包售卖
        :param selling_mode:
        :return:
        """
        self._selling_mode = selling_mode

    @property
    def source_name(self):
        """
        :return: mixed
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        课程来源名称
        :param source_name:
        :return:
        """
        self._source_name = source_name

    @property
    def tag_ids(self):
        """
        :return: mixed
        """
        return self._tag_ids

    @tag_ids.setter
    def tag_ids(self, tag_ids):
        """
        课程标签列表，请参见课程标签ID
        :param tag_ids:
        :return:
        """
        self._tag_ids = tag_ids

    @property
    def teachers(self):
        """
        :return: mixed
        """
        return self._teachers

    @teachers.setter
    def teachers(self, teachers):
        """
        课程教师ID列表
        :param teachers:
        :return:
        """
        self._teachers = teachers

    @property
    def type_id(self):
        """
        :return: mixed
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """
        课程类型
        :param type_id:
        :return:
        """
        self._type_id = type_id

    @property
    def validity_num(self):
        """
        :return: mixed
        """
        return self._validity_num

    @validity_num.setter
    def validity_num(self, validity_num):
        """
        课程订购关系有效期长度
        :param validity_num:
        :return:
        """
        self._validity_num = validity_num

    @property
    def validity_unit(self):
        """
        :return: mixed
        """
        return self._validity_unit

    @validity_unit.setter
    def validity_unit(self, validity_unit):
        """
        课程订购关系有效期长度单位
        :param validity_unit:
        :return:
        """
        self._validity_unit = validity_unit

    @property
    def media_type(self):
        """
        :return: mixed
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        课程媒体类型：1：音频 2：视频 3：绘本
        :param media_type:
        :return:
        """
        self._media_type = media_type

    @property
    def need_delivery(self):
        """
        :return: mixed
        """
        return self._need_delivery

    @need_delivery.setter
    def need_delivery(self, need_delivery):
        """
        课程购买后是否需要邮寄材料
        :param need_delivery:
        :return:
        """
        self._need_delivery = need_delivery

    @property
    def dev_product_id(self):
        """
        :return: mixed
        """
        return self._dev_product_id

    @dev_product_id.setter
    def dev_product_id(self, dev_product_id):
        """
        课程关联商品ID
        :param dev_product_id:
        :return:
        """
        self._dev_product_id = dev_product_id

    @property
    def refund_notify_url(self):
        """
        :return: mixed
        """
        return self._refund_notify_url

    @refund_notify_url.setter
    def refund_notify_url(self, refund_notify_url):
        """
        退款通知地址
        :param refund_notify_url:
        :return:
        """
        self._refund_notify_url = refund_notify_url



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from decimal import Decimal, ROUND_UP

import cv2

from edukit_sdk.edukit.common.model.image_file_info import ImageFileInfo
from edukit_sdk.edukit.common.model.media_file_info import MediaFileInfo


class MediaLocalizedData:
    def __init__(self):
        self._media_type = None
        self._frame_image_file_info = None
        self._ordinal = None
        self._media_file_info = None
        self._height = None
        self._width = None
        self._media_len = None

    @property
    def media_type(self):
        return self._media_type

    """
    * 媒体文件类型，定义如下，每次更新时必须携带此字段：
     * 1：课程介绍视频
     * 2：课程视频文件
     * 3：课程音频文件
     * 4：章节视频文件
     * 5：章节音频文件
     * 最小值 : 1
     * 最大值 : 5
     * 示例: 1
     * :param: mixed $mediaType
     * :return: MediaLocalizedData
    """

    @media_type.setter
    def media_type(self, media_type):
        self._media_type = media_type

    @property
    def height(self):
        return self._height

    """
     * 媒体文件纵向分辨率。
     * 分辨率仅对视频类型媒体文件有意义，对于音频类型的媒体文件，此字段将被忽略。
     * 首次提交视频媒体文件时，必须提供此字段。更新媒体文件信息时，如果文件大小没有变化，可不携带此字段，此时将保留当前值不变。
     * 分辨率单位为像素。
     * 最小值 : 0
     * 最大值 : 9999示例: 1080
     * :param: mixed heigth
     * :return: MediaLocalizedData
    """

    @height.setter
    def height(self, height):
        self._height = height

    @property
    def media_file_info(self):
        return self._media_file_info

    """
     * 媒体文件信息
     * :param: mixed media_file_info
     * :return: MediaLocalizedData
    """

    @media_file_info.setter
    def media_file_info(self, media_file_info: MediaFileInfo):
        self._media_file_info = media_file_info
        if self._media_file_info:
            video_capture = cv2.VideoCapture(self._media_file_info.path)

            if video_capture.isOpened():
                # 媒体文件横向分辨率
                self._width = video_capture.get(cv2.CAP_PROP_FRAME_WIDTH)
                # 媒体文件纵向分辨率
                self._height = video_capture.get(cv2.CAP_PROP_FRAME_HEIGHT)
                # 帧率
                rate = video_capture.get(cv2.CAP_PROP_FPS)
                # 帧数
                num = video_capture.get(cv2.CAP_PROP_FRAME_COUNT)
                if rate is not None and Decimal.from_float(rate) != 0:
                    # 媒体文件播放时长，时长单位为秒
                    self._media_len = str(
                        Decimal.from_float(num / rate).quantize(0, ROUND_UP))
            video_capture.release()

    @property
    def frame_image_file_info(self):
        return self._frame_image_file_info

    """
     * 宣传海报图片文件信息
     * :param: mixed frame_image_file_info
     * :return: MediaLocalizedData
    """

    @frame_image_file_info.setter
    def frame_image_file_info(self, frame_image_file_info: ImageFileInfo):
        self._frame_image_file_info = frame_image_file_info

    @property
    def ordinal(self):
        return self._ordinal

    """
     * 媒体序号。
     * 序号用于教育中心App中展示多个同类视频时进行排序。
        当前一个课程中只有介绍视频支持提供多个，
        因此序号只对mediaType=1的课程介绍视频有意义。
     * 教育中心App会优先展示序号值较小的视频。
     * 最小值 : 0
     * 最大值 : 5
     * 示例: 2
     * :param: mixed ordinal
     * :return: MediaLocalizedData
    """

    @ordinal.setter
    def ordinal(self, ordinal):
        self._ordinal = ordinal

    @property
    def media_len(self):
        return self._media_len

    """
     * 媒体文件播放时长，时长单位为秒。
     * 教育中心App中会向用户展示音频/视频文件的播放时长。
     * 首次提交媒体文件时，必须提供此字段。更新媒体文件信息时，如果播放时长没有变化，可不携带此字段，此时将保留当前值不变。
     * 最小值 : 0
     * 示例: 3600
     * :param: mixed media_len
     * :return: MediaLocalizedData
    """

    @media_len.setter
    def media_len(self, media_len):
        self._media_len = media_len

    @property
    def width(self):
        return self._width

    """
     * 媒体文件横向分辨率。
     * 分辨率仅对视频类型媒体文件有意义，对于音频类型的媒体文件，此字段将被忽略。
     * 首次提交视频媒体文件时，必须提供此字段。更新媒体文件信息时，如果文件大小没有变化，可不携带此字段，此时将保留当前值不变。
     * 分辨率单位为像素。
     * 最小值 : 0
     * 最大值 : 9999
     * 示例: 1920
     * :param: mixed width
     * :return: MediaLocalizedData
    """

    @width.setter
    def width(self, width):
        self._width = width



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.errorcode.abstract_error_code import \
    AbstractErrorCode


class TeacherErrorCode(AbstractErrorCode):
    INVALID_TEACHER_PARAMS_TEACHER = {0x1501: 'Teacher can not be null.'}
    INVALID_TEACHER_PARAMS_TEACHER_ID = {0x1502: 'Teacher ID can be null.'}
    INVALID_TEACHER_PARAMS_DEV_TEACHER_ID = {
        0x1503: 'DevTeacherId can not be null.'
    }
    INVALID_TEACHER_PARAMS_MATA_DATA = {0x1505: 'MataData can not be null.'}
    INVALID_TEACHER_PARAMS_LOCALIZED_DATA = {
        0x1506: 'LocalizedData can not be null, please check.'
    }

    def _init_(self, error):
        self._errorCode = ''
        self._errorDesc = None
        for k, v in error.items():
            self._errorCode = k
            self._errorDesc = v

    def get_error_code(self):
        """
        获取错误编码，后4位
        :return:errorCode
        """
        return self._errorCode

    def get_error_desc(self):
        """
        获取错误描述
        :return:errorDesc
        """
        return self._errorDesc



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class CourseCreateResponse(Response):
    def __init__(self):
        self._edit_id = None
        self._course_id = None
        self._update_meta_data_result = None
        self._update_localized_data_result = None
        self.update_product_price_result = None
        self.commit_result = None
        super(CourseCreateResponse, self).__init__()

    @property
    def update_meta_data_result(self):
        return self._update_meta_data_result

    @update_meta_data_result.setter
    def update_meta_data_result(self, update_meta_data_result):
        self._update_meta_data_result = update_meta_data_result

    @property
    def edit_id(self):
        return self._edit_id

    @edit_id.setter
    def edit_id(self, edit_id):
        self._edit_id = edit_id

    @property
    def course_id(self):
        return self._course_id

    @course_id.setter
    def course_id(self, course_id):
        self._course_id = course_id

    @property
    def update_product_price_result(self):
        return self._update_product_price_result

    @update_product_price_result.setter
    def update_product_price_result(self, update_product_price_result):
        self._update_product_price_result = update_product_price_result

    @property
    def commit_result(self):
        return self._commit_result

    @commit_result.setter
    def commit_result(self, commit_result):
        self._commit_result = commit_result

    @property
    def update_localized_data_result(self):
        return self._update_localized_data_result

    @update_localized_data_result.setter
    def update_localized_data_result(self, update_localized_data_result):
        self._update_localized_data_result = update_localized_data_result



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class BatchReportSignupCourseRequest:
    def __init__(self):
        self._status = None
        self._signup_list = None

    @property
    def status(self):
        """
        :return:
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        设置课程订购状态
        :param status: 2：已订购,4：已退订
        :return:
        """
        self._status = status

    @property
    def signup_list(self):
        """
        :return:
        """
        return self._signup_list

    @signup_list.setter
    def signup_list(self, signup_list):
        """
        设置多订单课程订购记录
        :param signup_list:
        :return:
        """
        self._signup_list = signup_list

    def to_json_string(self):
        """
        to_string
        :return:
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.catalogue.constant.catalogue_constant import \
    CatalogueConstant
from edukit_sdk.edukit.catalogue.model.catalogue import Catalogue
from edukit_sdk.edukit.catalogue.model.catalogue_edit_data import \
    CatalogueEditData
from edukit_sdk.edukit.catalogue.resp.create_catalogue_response import \
    CreateCatalogueResponse
from edukit_sdk.edukit.catalogue.resp.update_catalogue_response import \
    UpdateCatalogueResponse
from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse


class CatalogueHandler:
    def __init__(self, request_sender: EduKitRequestSender):
        self._request_sender = request_sender

    def create_catalogue(self, catalogue_edit_data: CatalogueEditData,
                         course_id, course_edit_id):
        logging.info('Call create_catalogue interface start.')
        create_catalogue_response = CreateCatalogueResponse()
        try:
            url = ApiConstant.CREATE_CATALOGUE_URL.format(
                course_id, course_edit_id)
            body = catalogue_edit_data.to_bytes()
            response = HttpCommonResponse(
                self._request_sender.post(url=url, body=body))
            create_catalogue_response = Helpers.parse_response(
                response.get_rsp(),
                CatalogueConstant.CREATE_CATALOGUE_RESPONSE)
            if create_catalogue_response and \
                    create_catalogue_response.result and \
                    create_catalogue_response.result.result_code \
                    != CommonConstant.RESULT_SUCCESS:
                result = create_catalogue_response.result
                logging.error(
                    'Call create_catalogue interface failed resultCode:'
                    '%s error_message:%s'
                    % (result.result_code, result.result_desc))
                return create_catalogue_response
        except EduKitException as e:
            logging.error(
                'Call create_catalogue interface failed. errorMessage:%s' %
                e.message)
            create_catalogue_response.result = Helpers\
                .build_error_result(CommonErrorCode.CALL_API_INTERFACE_FAILED)
        logging.info(
            'Call createCatalogue interface end, and '
            'catalogueId: %s, catalogueEditId: %s'
            % (create_catalogue_response.catalogue_id,
               create_catalogue_response.catalogue_edit_id))
        return create_catalogue_response

    def update_catalogue(self, catalogue: Catalogue, course_id,
                         course_edit_id):
        logging.info('Call update_catalogue interface start.')
        update_catalogue_response = UpdateCatalogueResponse()
        try:
            url = ApiConstant.UPDATE_CATALOGUE_URL.format(
                course_id, course_edit_id, catalogue.catalogue_id)
            body = catalogue.catalogue_edit.to_bytes()
            response = HttpCommonResponse(
                self._request_sender.put(url=url, body=body))
            update_catalogue_response = Helpers.parse_response(
                response.get_rsp(),
                CatalogueConstant.UPDATE_CATALOGUE_RESPONSE)
            result = update_catalogue_response.result
            if result and result.result_code \
                    != CommonConstant.RESULT_SUCCESS:
                logging.info(
                    'Call update_catalogue interface failed '
                    'and code: %s message: %s'
                    % (result.result_code, result.result_desc))
                return update_catalogue_response
        except EduKitException as e:
            logging.error(
                'Call updateCatalogue interface failed. errorMessage:%s' %
                e.message)
            update_catalogue_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        logging.info(
            'Call update_catalogue interface end, and catalogueEditId: %s' %
            update_catalogue_response.catalogue_edit_id)
        return update_catalogue_response

    def delete_catalogue(self, course_id, course_edit_id, catalogue_id):
        logging.info('Call delete_catalogue interface start.')
        try:
            url = ApiConstant.DELETE_CATALOGUE_URL.format(
                course_id, course_edit_id, catalogue_id)
            response = HttpCommonResponse(self._request_sender.delete(url=url))
            result = response.get_rsp()
            if not Helpers.is_success(result):
                logging.info(
                    'Call delete catalogue interface failed and code: %s '
                    'message: %s'
                    % (result.get(CatalogueConstant.RESULT).get(
                        CatalogueConstant.RESULT_CODE),
                       result.get(CatalogueConstant.RESULT).get(
                           CatalogueConstant.RESULT_DESC)))
                return Helpers.build_error_result(
                    CommonErrorCode.CALL_API_INTERFACE_FAILED)
            logging.info(
                'Call delete catalogue interface end. catalogueId: %s' %
                catalogue_id)
            return Helpers.build_result(result)
        except EduKitException as e:
            logging.error(
                'Call delete Catalogue interface failed. errorMessage:%s' %
                e.message)
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
